// The MIT License (MIT)

// Copyright (c) 2017-2020 Uber Technologies Inc.

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

// Code generated by protoc-gen-yarpc-go. DO NOT EDIT.
// source: uber/cadence/api/v1/service_workflow.proto

package apiv1

import (
	"context"
	"io/ioutil"
	"reflect"

	"github.com/gogo/protobuf/jsonpb"
	"github.com/gogo/protobuf/proto"
	"go.uber.org/fx"
	"go.uber.org/yarpc"
	"go.uber.org/yarpc/api/transport"
	"go.uber.org/yarpc/api/x/restriction"
	"go.uber.org/yarpc/encoding/protobuf"
	"go.uber.org/yarpc/encoding/protobuf/reflection"
)

var _ = ioutil.NopCloser

// WorkflowAPIYARPCClient is the YARPC client-side interface for the WorkflowAPI service.
type WorkflowAPIYARPCClient interface {
	StartWorkflowExecution(context.Context, *StartWorkflowExecutionRequest, ...yarpc.CallOption) (*StartWorkflowExecutionResponse, error)
	SignalWorkflowExecution(context.Context, *SignalWorkflowExecutionRequest, ...yarpc.CallOption) (*SignalWorkflowExecutionResponse, error)
	SignalWithStartWorkflowExecution(context.Context, *SignalWithStartWorkflowExecutionRequest, ...yarpc.CallOption) (*SignalWithStartWorkflowExecutionResponse, error)
	ResetWorkflowExecution(context.Context, *ResetWorkflowExecutionRequest, ...yarpc.CallOption) (*ResetWorkflowExecutionResponse, error)
	RequestCancelWorkflowExecution(context.Context, *RequestCancelWorkflowExecutionRequest, ...yarpc.CallOption) (*RequestCancelWorkflowExecutionResponse, error)
	TerminateWorkflowExecution(context.Context, *TerminateWorkflowExecutionRequest, ...yarpc.CallOption) (*TerminateWorkflowExecutionResponse, error)
	DescribeWorkflowExecution(context.Context, *DescribeWorkflowExecutionRequest, ...yarpc.CallOption) (*DescribeWorkflowExecutionResponse, error)
	QueryWorkflow(context.Context, *QueryWorkflowRequest, ...yarpc.CallOption) (*QueryWorkflowResponse, error)
	DescribeTaskList(context.Context, *DescribeTaskListRequest, ...yarpc.CallOption) (*DescribeTaskListResponse, error)
	ListTaskListPartitions(context.Context, *ListTaskListPartitionsRequest, ...yarpc.CallOption) (*ListTaskListPartitionsResponse, error)
	GetClusterInfo(context.Context, *GetClusterInfoRequest, ...yarpc.CallOption) (*GetClusterInfoResponse, error)
	GetWorkflowExecutionHistory(context.Context, *GetWorkflowExecutionHistoryRequest, ...yarpc.CallOption) (*GetWorkflowExecutionHistoryResponse, error)
}

func newWorkflowAPIYARPCClient(clientConfig transport.ClientConfig, anyResolver jsonpb.AnyResolver, options ...protobuf.ClientOption) WorkflowAPIYARPCClient {
	return &_WorkflowAPIYARPCCaller{protobuf.NewStreamClient(
		protobuf.ClientParams{
			ServiceName:  "uber.cadence.api.v1.WorkflowAPI",
			ClientConfig: clientConfig,
			AnyResolver:  anyResolver,
			Options:      options,
		},
	)}
}

// NewWorkflowAPIYARPCClient builds a new YARPC client for the WorkflowAPI service.
func NewWorkflowAPIYARPCClient(clientConfig transport.ClientConfig, options ...protobuf.ClientOption) WorkflowAPIYARPCClient {
	return newWorkflowAPIYARPCClient(clientConfig, nil, options...)
}

// WorkflowAPIYARPCServer is the YARPC server-side interface for the WorkflowAPI service.
type WorkflowAPIYARPCServer interface {
	StartWorkflowExecution(context.Context, *StartWorkflowExecutionRequest) (*StartWorkflowExecutionResponse, error)
	SignalWorkflowExecution(context.Context, *SignalWorkflowExecutionRequest) (*SignalWorkflowExecutionResponse, error)
	SignalWithStartWorkflowExecution(context.Context, *SignalWithStartWorkflowExecutionRequest) (*SignalWithStartWorkflowExecutionResponse, error)
	ResetWorkflowExecution(context.Context, *ResetWorkflowExecutionRequest) (*ResetWorkflowExecutionResponse, error)
	RequestCancelWorkflowExecution(context.Context, *RequestCancelWorkflowExecutionRequest) (*RequestCancelWorkflowExecutionResponse, error)
	TerminateWorkflowExecution(context.Context, *TerminateWorkflowExecutionRequest) (*TerminateWorkflowExecutionResponse, error)
	DescribeWorkflowExecution(context.Context, *DescribeWorkflowExecutionRequest) (*DescribeWorkflowExecutionResponse, error)
	QueryWorkflow(context.Context, *QueryWorkflowRequest) (*QueryWorkflowResponse, error)
	DescribeTaskList(context.Context, *DescribeTaskListRequest) (*DescribeTaskListResponse, error)
	ListTaskListPartitions(context.Context, *ListTaskListPartitionsRequest) (*ListTaskListPartitionsResponse, error)
	GetClusterInfo(context.Context, *GetClusterInfoRequest) (*GetClusterInfoResponse, error)
	GetWorkflowExecutionHistory(context.Context, *GetWorkflowExecutionHistoryRequest) (*GetWorkflowExecutionHistoryResponse, error)
}

type buildWorkflowAPIYARPCProceduresParams struct {
	Server      WorkflowAPIYARPCServer
	AnyResolver jsonpb.AnyResolver
}

func buildWorkflowAPIYARPCProcedures(params buildWorkflowAPIYARPCProceduresParams) []transport.Procedure {
	handler := &_WorkflowAPIYARPCHandler{params.Server}
	return protobuf.BuildProcedures(
		protobuf.BuildProceduresParams{
			ServiceName: "uber.cadence.api.v1.WorkflowAPI",
			UnaryHandlerParams: []protobuf.BuildProceduresUnaryHandlerParams{
				{
					MethodName: "StartWorkflowExecution",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.StartWorkflowExecution,
							NewRequest:  newWorkflowAPIServiceStartWorkflowExecutionYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
				{
					MethodName: "SignalWorkflowExecution",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.SignalWorkflowExecution,
							NewRequest:  newWorkflowAPIServiceSignalWorkflowExecutionYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
				{
					MethodName: "SignalWithStartWorkflowExecution",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.SignalWithStartWorkflowExecution,
							NewRequest:  newWorkflowAPIServiceSignalWithStartWorkflowExecutionYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
				{
					MethodName: "ResetWorkflowExecution",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.ResetWorkflowExecution,
							NewRequest:  newWorkflowAPIServiceResetWorkflowExecutionYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
				{
					MethodName: "RequestCancelWorkflowExecution",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.RequestCancelWorkflowExecution,
							NewRequest:  newWorkflowAPIServiceRequestCancelWorkflowExecutionYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
				{
					MethodName: "TerminateWorkflowExecution",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.TerminateWorkflowExecution,
							NewRequest:  newWorkflowAPIServiceTerminateWorkflowExecutionYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
				{
					MethodName: "DescribeWorkflowExecution",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.DescribeWorkflowExecution,
							NewRequest:  newWorkflowAPIServiceDescribeWorkflowExecutionYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
				{
					MethodName: "QueryWorkflow",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.QueryWorkflow,
							NewRequest:  newWorkflowAPIServiceQueryWorkflowYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
				{
					MethodName: "DescribeTaskList",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.DescribeTaskList,
							NewRequest:  newWorkflowAPIServiceDescribeTaskListYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
				{
					MethodName: "ListTaskListPartitions",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.ListTaskListPartitions,
							NewRequest:  newWorkflowAPIServiceListTaskListPartitionsYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
				{
					MethodName: "GetClusterInfo",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.GetClusterInfo,
							NewRequest:  newWorkflowAPIServiceGetClusterInfoYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
				{
					MethodName: "GetWorkflowExecutionHistory",
					Handler: protobuf.NewUnaryHandler(
						protobuf.UnaryHandlerParams{
							Handle:      handler.GetWorkflowExecutionHistory,
							NewRequest:  newWorkflowAPIServiceGetWorkflowExecutionHistoryYARPCRequest,
							AnyResolver: params.AnyResolver,
						},
					),
				},
			},
			OnewayHandlerParams: []protobuf.BuildProceduresOnewayHandlerParams{},
			StreamHandlerParams: []protobuf.BuildProceduresStreamHandlerParams{},
		},
	)
}

// BuildWorkflowAPIYARPCProcedures prepares an implementation of the WorkflowAPI service for YARPC registration.
func BuildWorkflowAPIYARPCProcedures(server WorkflowAPIYARPCServer) []transport.Procedure {
	return buildWorkflowAPIYARPCProcedures(buildWorkflowAPIYARPCProceduresParams{Server: server})
}

// FxWorkflowAPIYARPCClientParams defines the input
// for NewFxWorkflowAPIYARPCClient. It provides the
// paramaters to get a WorkflowAPIYARPCClient in an
// Fx application.
type FxWorkflowAPIYARPCClientParams struct {
	fx.In

	Provider    yarpc.ClientConfig
	AnyResolver jsonpb.AnyResolver  `name:"yarpcfx" optional:"true"`
	Restriction restriction.Checker `optional:"true"`
}

// FxWorkflowAPIYARPCClientResult defines the output
// of NewFxWorkflowAPIYARPCClient. It provides a
// WorkflowAPIYARPCClient to an Fx application.
type FxWorkflowAPIYARPCClientResult struct {
	fx.Out

	Client WorkflowAPIYARPCClient

	// We are using an fx.Out struct here instead of just returning a client
	// so that we can add more values or add named versions of the client in
	// the future without breaking any existing code.
}

// NewFxWorkflowAPIYARPCClient provides a WorkflowAPIYARPCClient
// to an Fx application using the given name for routing.
//
//  fx.Provide(
//    apiv1.NewFxWorkflowAPIYARPCClient("service-name"),
//    ...
//  )
func NewFxWorkflowAPIYARPCClient(name string, options ...protobuf.ClientOption) interface{} {
	return func(params FxWorkflowAPIYARPCClientParams) FxWorkflowAPIYARPCClientResult {
		cc := params.Provider.ClientConfig(name)

		if params.Restriction != nil {
			if namer, ok := cc.GetUnaryOutbound().(transport.Namer); ok {
				if err := params.Restriction.Check(protobuf.Encoding, namer.TransportName()); err != nil {
					panic(err.Error())
				}
			}
		}

		return FxWorkflowAPIYARPCClientResult{
			Client: newWorkflowAPIYARPCClient(cc, params.AnyResolver, options...),
		}
	}
}

// FxWorkflowAPIYARPCProceduresParams defines the input
// for NewFxWorkflowAPIYARPCProcedures. It provides the
// paramaters to get WorkflowAPIYARPCServer procedures in an
// Fx application.
type FxWorkflowAPIYARPCProceduresParams struct {
	fx.In

	Server      WorkflowAPIYARPCServer
	AnyResolver jsonpb.AnyResolver `name:"yarpcfx" optional:"true"`
}

// FxWorkflowAPIYARPCProceduresResult defines the output
// of NewFxWorkflowAPIYARPCProcedures. It provides
// WorkflowAPIYARPCServer procedures to an Fx application.
//
// The procedures are provided to the "yarpcfx" value group.
// Dig 1.2 or newer must be used for this feature to work.
type FxWorkflowAPIYARPCProceduresResult struct {
	fx.Out

	Procedures     []transport.Procedure `group:"yarpcfx"`
	ReflectionMeta reflection.ServerMeta `group:"yarpcfx"`
}

// NewFxWorkflowAPIYARPCProcedures provides WorkflowAPIYARPCServer procedures to an Fx application.
// It expects a WorkflowAPIYARPCServer to be present in the container.
//
//  fx.Provide(
//    apiv1.NewFxWorkflowAPIYARPCProcedures(),
//    ...
//  )
func NewFxWorkflowAPIYARPCProcedures() interface{} {
	return func(params FxWorkflowAPIYARPCProceduresParams) FxWorkflowAPIYARPCProceduresResult {
		return FxWorkflowAPIYARPCProceduresResult{
			Procedures: buildWorkflowAPIYARPCProcedures(buildWorkflowAPIYARPCProceduresParams{
				Server:      params.Server,
				AnyResolver: params.AnyResolver,
			}),
			ReflectionMeta: reflection.ServerMeta{
				ServiceName:     "uber.cadence.api.v1.WorkflowAPI",
				FileDescriptors: yarpcFileDescriptorClosure674d14d2fee4e473,
			},
		}
	}
}

type _WorkflowAPIYARPCCaller struct {
	streamClient protobuf.StreamClient
}

func (c *_WorkflowAPIYARPCCaller) StartWorkflowExecution(ctx context.Context, request *StartWorkflowExecutionRequest, options ...yarpc.CallOption) (*StartWorkflowExecutionResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "StartWorkflowExecution", request, newWorkflowAPIServiceStartWorkflowExecutionYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*StartWorkflowExecutionResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceStartWorkflowExecutionYARPCResponse, responseMessage)
	}
	return response, err
}

func (c *_WorkflowAPIYARPCCaller) SignalWorkflowExecution(ctx context.Context, request *SignalWorkflowExecutionRequest, options ...yarpc.CallOption) (*SignalWorkflowExecutionResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "SignalWorkflowExecution", request, newWorkflowAPIServiceSignalWorkflowExecutionYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*SignalWorkflowExecutionResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceSignalWorkflowExecutionYARPCResponse, responseMessage)
	}
	return response, err
}

func (c *_WorkflowAPIYARPCCaller) SignalWithStartWorkflowExecution(ctx context.Context, request *SignalWithStartWorkflowExecutionRequest, options ...yarpc.CallOption) (*SignalWithStartWorkflowExecutionResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "SignalWithStartWorkflowExecution", request, newWorkflowAPIServiceSignalWithStartWorkflowExecutionYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*SignalWithStartWorkflowExecutionResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceSignalWithStartWorkflowExecutionYARPCResponse, responseMessage)
	}
	return response, err
}

func (c *_WorkflowAPIYARPCCaller) ResetWorkflowExecution(ctx context.Context, request *ResetWorkflowExecutionRequest, options ...yarpc.CallOption) (*ResetWorkflowExecutionResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "ResetWorkflowExecution", request, newWorkflowAPIServiceResetWorkflowExecutionYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*ResetWorkflowExecutionResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceResetWorkflowExecutionYARPCResponse, responseMessage)
	}
	return response, err
}

func (c *_WorkflowAPIYARPCCaller) RequestCancelWorkflowExecution(ctx context.Context, request *RequestCancelWorkflowExecutionRequest, options ...yarpc.CallOption) (*RequestCancelWorkflowExecutionResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "RequestCancelWorkflowExecution", request, newWorkflowAPIServiceRequestCancelWorkflowExecutionYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*RequestCancelWorkflowExecutionResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceRequestCancelWorkflowExecutionYARPCResponse, responseMessage)
	}
	return response, err
}

func (c *_WorkflowAPIYARPCCaller) TerminateWorkflowExecution(ctx context.Context, request *TerminateWorkflowExecutionRequest, options ...yarpc.CallOption) (*TerminateWorkflowExecutionResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "TerminateWorkflowExecution", request, newWorkflowAPIServiceTerminateWorkflowExecutionYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*TerminateWorkflowExecutionResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceTerminateWorkflowExecutionYARPCResponse, responseMessage)
	}
	return response, err
}

func (c *_WorkflowAPIYARPCCaller) DescribeWorkflowExecution(ctx context.Context, request *DescribeWorkflowExecutionRequest, options ...yarpc.CallOption) (*DescribeWorkflowExecutionResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "DescribeWorkflowExecution", request, newWorkflowAPIServiceDescribeWorkflowExecutionYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*DescribeWorkflowExecutionResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceDescribeWorkflowExecutionYARPCResponse, responseMessage)
	}
	return response, err
}

func (c *_WorkflowAPIYARPCCaller) QueryWorkflow(ctx context.Context, request *QueryWorkflowRequest, options ...yarpc.CallOption) (*QueryWorkflowResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "QueryWorkflow", request, newWorkflowAPIServiceQueryWorkflowYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*QueryWorkflowResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceQueryWorkflowYARPCResponse, responseMessage)
	}
	return response, err
}

func (c *_WorkflowAPIYARPCCaller) DescribeTaskList(ctx context.Context, request *DescribeTaskListRequest, options ...yarpc.CallOption) (*DescribeTaskListResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "DescribeTaskList", request, newWorkflowAPIServiceDescribeTaskListYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*DescribeTaskListResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceDescribeTaskListYARPCResponse, responseMessage)
	}
	return response, err
}

func (c *_WorkflowAPIYARPCCaller) ListTaskListPartitions(ctx context.Context, request *ListTaskListPartitionsRequest, options ...yarpc.CallOption) (*ListTaskListPartitionsResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "ListTaskListPartitions", request, newWorkflowAPIServiceListTaskListPartitionsYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*ListTaskListPartitionsResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceListTaskListPartitionsYARPCResponse, responseMessage)
	}
	return response, err
}

func (c *_WorkflowAPIYARPCCaller) GetClusterInfo(ctx context.Context, request *GetClusterInfoRequest, options ...yarpc.CallOption) (*GetClusterInfoResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "GetClusterInfo", request, newWorkflowAPIServiceGetClusterInfoYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*GetClusterInfoResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceGetClusterInfoYARPCResponse, responseMessage)
	}
	return response, err
}

func (c *_WorkflowAPIYARPCCaller) GetWorkflowExecutionHistory(ctx context.Context, request *GetWorkflowExecutionHistoryRequest, options ...yarpc.CallOption) (*GetWorkflowExecutionHistoryResponse, error) {
	responseMessage, err := c.streamClient.Call(ctx, "GetWorkflowExecutionHistory", request, newWorkflowAPIServiceGetWorkflowExecutionHistoryYARPCResponse, options...)
	if responseMessage == nil {
		return nil, err
	}
	response, ok := responseMessage.(*GetWorkflowExecutionHistoryResponse)
	if !ok {
		return nil, protobuf.CastError(emptyWorkflowAPIServiceGetWorkflowExecutionHistoryYARPCResponse, responseMessage)
	}
	return response, err
}

type _WorkflowAPIYARPCHandler struct {
	server WorkflowAPIYARPCServer
}

func (h *_WorkflowAPIYARPCHandler) StartWorkflowExecution(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *StartWorkflowExecutionRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*StartWorkflowExecutionRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceStartWorkflowExecutionYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.StartWorkflowExecution(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func (h *_WorkflowAPIYARPCHandler) SignalWorkflowExecution(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *SignalWorkflowExecutionRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*SignalWorkflowExecutionRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceSignalWorkflowExecutionYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.SignalWorkflowExecution(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func (h *_WorkflowAPIYARPCHandler) SignalWithStartWorkflowExecution(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *SignalWithStartWorkflowExecutionRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*SignalWithStartWorkflowExecutionRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceSignalWithStartWorkflowExecutionYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.SignalWithStartWorkflowExecution(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func (h *_WorkflowAPIYARPCHandler) ResetWorkflowExecution(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *ResetWorkflowExecutionRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*ResetWorkflowExecutionRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceResetWorkflowExecutionYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.ResetWorkflowExecution(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func (h *_WorkflowAPIYARPCHandler) RequestCancelWorkflowExecution(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *RequestCancelWorkflowExecutionRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*RequestCancelWorkflowExecutionRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceRequestCancelWorkflowExecutionYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.RequestCancelWorkflowExecution(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func (h *_WorkflowAPIYARPCHandler) TerminateWorkflowExecution(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *TerminateWorkflowExecutionRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*TerminateWorkflowExecutionRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceTerminateWorkflowExecutionYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.TerminateWorkflowExecution(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func (h *_WorkflowAPIYARPCHandler) DescribeWorkflowExecution(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *DescribeWorkflowExecutionRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*DescribeWorkflowExecutionRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceDescribeWorkflowExecutionYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.DescribeWorkflowExecution(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func (h *_WorkflowAPIYARPCHandler) QueryWorkflow(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *QueryWorkflowRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*QueryWorkflowRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceQueryWorkflowYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.QueryWorkflow(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func (h *_WorkflowAPIYARPCHandler) DescribeTaskList(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *DescribeTaskListRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*DescribeTaskListRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceDescribeTaskListYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.DescribeTaskList(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func (h *_WorkflowAPIYARPCHandler) ListTaskListPartitions(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *ListTaskListPartitionsRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*ListTaskListPartitionsRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceListTaskListPartitionsYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.ListTaskListPartitions(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func (h *_WorkflowAPIYARPCHandler) GetClusterInfo(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *GetClusterInfoRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*GetClusterInfoRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceGetClusterInfoYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.GetClusterInfo(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func (h *_WorkflowAPIYARPCHandler) GetWorkflowExecutionHistory(ctx context.Context, requestMessage proto.Message) (proto.Message, error) {
	var request *GetWorkflowExecutionHistoryRequest
	var ok bool
	if requestMessage != nil {
		request, ok = requestMessage.(*GetWorkflowExecutionHistoryRequest)
		if !ok {
			return nil, protobuf.CastError(emptyWorkflowAPIServiceGetWorkflowExecutionHistoryYARPCRequest, requestMessage)
		}
	}
	response, err := h.server.GetWorkflowExecutionHistory(ctx, request)
	if response == nil {
		return nil, err
	}
	return response, err
}

func newWorkflowAPIServiceStartWorkflowExecutionYARPCRequest() proto.Message {
	return &StartWorkflowExecutionRequest{}
}

func newWorkflowAPIServiceStartWorkflowExecutionYARPCResponse() proto.Message {
	return &StartWorkflowExecutionResponse{}
}

func newWorkflowAPIServiceSignalWorkflowExecutionYARPCRequest() proto.Message {
	return &SignalWorkflowExecutionRequest{}
}

func newWorkflowAPIServiceSignalWorkflowExecutionYARPCResponse() proto.Message {
	return &SignalWorkflowExecutionResponse{}
}

func newWorkflowAPIServiceSignalWithStartWorkflowExecutionYARPCRequest() proto.Message {
	return &SignalWithStartWorkflowExecutionRequest{}
}

func newWorkflowAPIServiceSignalWithStartWorkflowExecutionYARPCResponse() proto.Message {
	return &SignalWithStartWorkflowExecutionResponse{}
}

func newWorkflowAPIServiceResetWorkflowExecutionYARPCRequest() proto.Message {
	return &ResetWorkflowExecutionRequest{}
}

func newWorkflowAPIServiceResetWorkflowExecutionYARPCResponse() proto.Message {
	return &ResetWorkflowExecutionResponse{}
}

func newWorkflowAPIServiceRequestCancelWorkflowExecutionYARPCRequest() proto.Message {
	return &RequestCancelWorkflowExecutionRequest{}
}

func newWorkflowAPIServiceRequestCancelWorkflowExecutionYARPCResponse() proto.Message {
	return &RequestCancelWorkflowExecutionResponse{}
}

func newWorkflowAPIServiceTerminateWorkflowExecutionYARPCRequest() proto.Message {
	return &TerminateWorkflowExecutionRequest{}
}

func newWorkflowAPIServiceTerminateWorkflowExecutionYARPCResponse() proto.Message {
	return &TerminateWorkflowExecutionResponse{}
}

func newWorkflowAPIServiceDescribeWorkflowExecutionYARPCRequest() proto.Message {
	return &DescribeWorkflowExecutionRequest{}
}

func newWorkflowAPIServiceDescribeWorkflowExecutionYARPCResponse() proto.Message {
	return &DescribeWorkflowExecutionResponse{}
}

func newWorkflowAPIServiceQueryWorkflowYARPCRequest() proto.Message {
	return &QueryWorkflowRequest{}
}

func newWorkflowAPIServiceQueryWorkflowYARPCResponse() proto.Message {
	return &QueryWorkflowResponse{}
}

func newWorkflowAPIServiceDescribeTaskListYARPCRequest() proto.Message {
	return &DescribeTaskListRequest{}
}

func newWorkflowAPIServiceDescribeTaskListYARPCResponse() proto.Message {
	return &DescribeTaskListResponse{}
}

func newWorkflowAPIServiceListTaskListPartitionsYARPCRequest() proto.Message {
	return &ListTaskListPartitionsRequest{}
}

func newWorkflowAPIServiceListTaskListPartitionsYARPCResponse() proto.Message {
	return &ListTaskListPartitionsResponse{}
}

func newWorkflowAPIServiceGetClusterInfoYARPCRequest() proto.Message {
	return &GetClusterInfoRequest{}
}

func newWorkflowAPIServiceGetClusterInfoYARPCResponse() proto.Message {
	return &GetClusterInfoResponse{}
}

func newWorkflowAPIServiceGetWorkflowExecutionHistoryYARPCRequest() proto.Message {
	return &GetWorkflowExecutionHistoryRequest{}
}

func newWorkflowAPIServiceGetWorkflowExecutionHistoryYARPCResponse() proto.Message {
	return &GetWorkflowExecutionHistoryResponse{}
}

var (
	emptyWorkflowAPIServiceStartWorkflowExecutionYARPCRequest            = &StartWorkflowExecutionRequest{}
	emptyWorkflowAPIServiceStartWorkflowExecutionYARPCResponse           = &StartWorkflowExecutionResponse{}
	emptyWorkflowAPIServiceSignalWorkflowExecutionYARPCRequest           = &SignalWorkflowExecutionRequest{}
	emptyWorkflowAPIServiceSignalWorkflowExecutionYARPCResponse          = &SignalWorkflowExecutionResponse{}
	emptyWorkflowAPIServiceSignalWithStartWorkflowExecutionYARPCRequest  = &SignalWithStartWorkflowExecutionRequest{}
	emptyWorkflowAPIServiceSignalWithStartWorkflowExecutionYARPCResponse = &SignalWithStartWorkflowExecutionResponse{}
	emptyWorkflowAPIServiceResetWorkflowExecutionYARPCRequest            = &ResetWorkflowExecutionRequest{}
	emptyWorkflowAPIServiceResetWorkflowExecutionYARPCResponse           = &ResetWorkflowExecutionResponse{}
	emptyWorkflowAPIServiceRequestCancelWorkflowExecutionYARPCRequest    = &RequestCancelWorkflowExecutionRequest{}
	emptyWorkflowAPIServiceRequestCancelWorkflowExecutionYARPCResponse   = &RequestCancelWorkflowExecutionResponse{}
	emptyWorkflowAPIServiceTerminateWorkflowExecutionYARPCRequest        = &TerminateWorkflowExecutionRequest{}
	emptyWorkflowAPIServiceTerminateWorkflowExecutionYARPCResponse       = &TerminateWorkflowExecutionResponse{}
	emptyWorkflowAPIServiceDescribeWorkflowExecutionYARPCRequest         = &DescribeWorkflowExecutionRequest{}
	emptyWorkflowAPIServiceDescribeWorkflowExecutionYARPCResponse        = &DescribeWorkflowExecutionResponse{}
	emptyWorkflowAPIServiceQueryWorkflowYARPCRequest                     = &QueryWorkflowRequest{}
	emptyWorkflowAPIServiceQueryWorkflowYARPCResponse                    = &QueryWorkflowResponse{}
	emptyWorkflowAPIServiceDescribeTaskListYARPCRequest                  = &DescribeTaskListRequest{}
	emptyWorkflowAPIServiceDescribeTaskListYARPCResponse                 = &DescribeTaskListResponse{}
	emptyWorkflowAPIServiceListTaskListPartitionsYARPCRequest            = &ListTaskListPartitionsRequest{}
	emptyWorkflowAPIServiceListTaskListPartitionsYARPCResponse           = &ListTaskListPartitionsResponse{}
	emptyWorkflowAPIServiceGetClusterInfoYARPCRequest                    = &GetClusterInfoRequest{}
	emptyWorkflowAPIServiceGetClusterInfoYARPCResponse                   = &GetClusterInfoResponse{}
	emptyWorkflowAPIServiceGetWorkflowExecutionHistoryYARPCRequest       = &GetWorkflowExecutionHistoryRequest{}
	emptyWorkflowAPIServiceGetWorkflowExecutionHistoryYARPCResponse      = &GetWorkflowExecutionHistoryResponse{}
)

var yarpcFileDescriptorClosure674d14d2fee4e473 = [][]byte{
	// uber/cadence/api/v1/service_workflow.proto
	[]byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xdc, 0x59, 0x4f, 0x73, 0xdb, 0xc6,
		0x15, 0x1f, 0x88, 0xfa, 0x43, 0x3d, 0x52, 0xb2, 0xbd, 0x89, 0x24, 0x98, 0x8e, 0x6c, 0x09, 0x4e,
		0x52, 0xd5, 0x89, 0xa9, 0xb1, 0xdc, 0xda, 0xa9, 0xd3, 0x36, 0x23, 0xd3, 0x96, 0xa3, 0x99, 0x38,
		0xa3, 0x42, 0x6a, 0x3c, 0xed, 0x05, 0xb3, 0x02, 0x9e, 0xc8, 0xad, 0x40, 0x2c, 0xb4, 0xbb, 0x10,
		0xc3, 0xdc, 0xda, 0xc9, 0xf4, 0xd0, 0x4e, 0x67, 0xda, 0x63, 0x4f, 0x3d, 0xb4, 0xe7, 0x7e, 0x8c,
		0x1e, 0x7a, 0x6b, 0xbf, 0x41, 0x3f, 0x41, 0xbf, 0x41, 0xa6, 0x83, 0xc5, 0x82, 0x12, 0x29, 0x10,
		0x94, 0xdc, 0xe9, 0xc4, 0xd3, 0x1b, 0xf1, 0xf6, 0xfd, 0x7e, 0xbb, 0xef, 0xcf, 0x3e, 0xbc, 0x07,
		0xc2, 0xbd, 0xe4, 0x10, 0xc5, 0xa6, 0x4f, 0x03, 0x8c, 0x7c, 0xdc, 0xa4, 0x31, 0xdb, 0x3c, 0x7d,
		0xb0, 0x29, 0x51, 0x9c, 0x32, 0x1f, 0xbd, 0x1e, 0x17, 0xc7, 0x47, 0x21, 0xef, 0x35, 0x63, 0xc1,
		0x15, 0x27, 0x6f, 0xa5, 0xba, 0x4d, 0xa3, 0xdb, 0xa4, 0x31, 0x6b, 0x9e, 0x3e, 0x68, 0xdc, 0x6e,
		0x73, 0xde, 0x0e, 0x71, 0x53, 0xab, 0x1c, 0x26, 0x47, 0x9b, 0x41, 0x22, 0xa8, 0x62, 0x3c, 0xca,
		0x40, 0x8d, 0xb5, 0xa2, 0x0d, 0x7c, 0xde, 0xed, 0x0e, 0x34, 0xd6, 0x8b, 0x34, 0x3a, 0x4c, 0x2a,
		0x2e, 0xfa, 0x46, 0xe5, 0x4e, 0x91, 0xca, 0x49, 0x82, 0x03, 0x05, 0xa7, 0x48, 0x41, 0x51, 0x79,
		0x1c, 0x32, 0xa9, 0xca, 0x74, 0x86, 0x4d, 0x74, 0xfe, 0x3e, 0x07, 0xab, 0xfb, 0x8a, 0x0a, 0xf5,
		0xca, 0xc8, 0x9f, 0x7f, 0x89, 0x7e, 0x92, 0x9a, 0xe3, 0xe2, 0x49, 0x82, 0x52, 0x91, 0x65, 0x98,
		0x0d, 0x78, 0x97, 0xb2, 0xc8, 0xb6, 0xd6, 0xac, 0x8d, 0x79, 0xd7, 0x3c, 0x91, 0x3b, 0x50, 0xcb,
		0xb9, 0x3c, 0x16, 0xd8, 0x53, 0x7a, 0x11, 0x72, 0xd1, 0x6e, 0x40, 0x76, 0x60, 0x61, 0xa0, 0xa0,
		0xfa, 0x31, 0xda, 0x95, 0x35, 0x6b, 0xa3, 0xb6, 0xb5, 0xde, 0x2c, 0xf0, 0x6a, 0x33, 0xdf, 0xfe,
		0xa0, 0x1f, 0xa3, 0x5b, 0xef, 0x9d, 0x7b, 0x22, 0x4f, 0x60, 0x3e, 0x35, 0xcc, 0x4b, 0x2d, 0xb3,
		0xa7, 0x35, 0xc7, 0x6a, 0x21, 0xc7, 0x01, 0x95, 0xc7, 0x9f, 0x31, 0xa9, 0xdc, 0xaa, 0x32, 0xbf,
		0xc8, 0x16, 0xcc, 0xb0, 0x28, 0x4e, 0x94, 0x3d, 0xa3, 0x71, 0xef, 0x14, 0xe2, 0xf6, 0x68, 0x3f,
		0xe4, 0x34, 0x70, 0x33, 0x55, 0x42, 0x61, 0x0d, 0x73, 0x27, 0x78, 0x32, 0xf5, 0x8d, 0xa7, 0xb8,
		0xe7, 0x87, 0x5c, 0xa2, 0xa7, 0x58, 0x17, 0x79, 0xa2, 0xec, 0x59, 0x4d, 0x77, 0xb3, 0x99, 0xe5,
		0x42, 0x33, 0xcf, 0x85, 0xe6, 0x33, 0x93, 0x0b, 0xee, 0x3b, 0x03, 0x0a, 0xed, 0xdd, 0x03, 0xde,
		0x4a, 0xf1, 0x07, 0x19, 0x9c, 0xbc, 0x82, 0x5b, 0xda, 0xa4, 0x31, 0xec, 0x73, 0x93, 0xd8, 0x57,
		0x52, 0x74, 0x11, 0x71, 0x03, 0xaa, 0x2c, 0xc0, 0x48, 0x31, 0xd5, 0xb7, 0xab, 0x3a, 0x22, 0x83,
		0x67, 0xb2, 0x0a, 0x20, 0xb2, 0x98, 0xa6, 0xf1, 0x9a, 0xd7, 0xab, 0xf3, 0x46, 0xb2, 0x1b, 0x10,
		0x1f, 0xec, 0x73, 0xf1, 0xf4, 0x04, 0x26, 0x12, 0xbd, 0x98, 0x87, 0xcc, 0xef, 0xdb, 0xb0, 0x66,
		0x6d, 0x2c, 0x6e, 0xdd, 0x2b, 0x8d, 0xdc, 0x6e, 0xe0, 0xa6, 0x90, 0x3d, 0x8d, 0x70, 0x97, 0x7a,
		0x45, 0x62, 0xd2, 0x82, 0xba, 0x40, 0x25, 0xfa, 0x39, 0x71, 0x4d, 0x5b, 0xba, 0x56, 0x48, 0xec,
		0xa6, 0x8a, 0x86, 0xae, 0x26, 0xce, 0x1e, 0xc8, 0x5d, 0x58, 0xf0, 0x45, 0x1a, 0x1b, 0xbf, 0x83,
		0x41, 0x12, 0xa2, 0x5d, 0xd7, 0xb6, 0xd4, 0x53, 0xe1, 0xbe, 0x91, 0x91, 0xfb, 0x30, 0xdd, 0xc5,
		0x2e, 0xb7, 0x17, 0x8c, 0x2f, 0x8b, 0x76, 0x78, 0x89, 0x5d, 0xee, 0x6a, 0x35, 0xe2, 0xc2, 0x0d,
		0x89, 0x54, 0xf8, 0x1d, 0x8f, 0x2a, 0x25, 0xd8, 0x61, 0xa2, 0x50, 0xda, 0x8b, 0x1a, 0xfb, 0x5e,
		0x21, 0x76, 0x5f, 0x6b, 0x6f, 0x0f, 0x94, 0xdd, 0xeb, 0x72, 0x44, 0x42, 0x1e, 0xc2, 0x6c, 0x07,
		0x69, 0x80, 0xc2, 0xbe, 0xa6, 0x89, 0x6e, 0x15, 0x12, 0x7d, 0xaa, 0x55, 0x5c, 0xa3, 0x4a, 0x9e,
		0x40, 0x2d, 0xc0, 0x90, 0xf6, 0xb3, 0xdc, 0xb0, 0xaf, 0x4f, 0x4a, 0x05, 0xd0, 0xda, 0x3a, 0x17,
		0x9c, 0xc7, 0x70, 0x7b, 0xdc, 0x5d, 0x96, 0x31, 0x8f, 0x24, 0x92, 0x25, 0x98, 0x15, 0x49, 0x94,
		0xc6, 0x3f, 0xbb, 0xcc, 0x33, 0x22, 0x89, 0x76, 0x03, 0xe7, 0x6f, 0x53, 0x70, 0x7b, 0x9f, 0xb5,
		0x23, 0x1a, 0x5e, 0xb9, 0x0c, 0xfc, 0x14, 0xc8, 0x20, 0x6d, 0x06, 0x39, 0xaf, 0xab, 0x41, 0x6d,
		0xeb, 0xfd, 0xd2, 0x84, 0x39, 0xdb, 0xe2, 0x46, 0x6f, 0x54, 0x34, 0x94, 0xc8, 0x95, 0xd2, 0x44,
		0x9e, 0x1e, 0x4d, 0xe4, 0x3b, 0x50, 0x93, 0xda, 0x16, 0x2f, 0xa2, 0x5d, 0xd4, 0x37, 0x7f, 0xde,
		0x85, 0x4c, 0xf4, 0x39, 0xed, 0x22, 0xf9, 0x04, 0xea, 0x46, 0x21, 0xab, 0x0d, 0xb3, 0x97, 0xa8,
		0x0d, 0x86, 0x72, 0x57, 0x57, 0x08, 0x1b, 0xe6, 0x7c, 0x1e, 0x29, 0xc1, 0x43, 0x7d, 0x55, 0xeb,
		0x6e, 0xfe, 0xe8, 0xac, 0xc3, 0x9d, 0xb1, 0x7e, 0xcc, 0x42, 0xe0, 0x7c, 0x63, 0xc1, 0x77, 0x8c,
		0x0e, 0x53, 0x9d, 0xf2, 0xda, 0xfb, 0x0a, 0x16, 0xb2, 0x12, 0x61, 0xac, 0xd3, 0xbe, 0xaf, 0x6d,
		0x6d, 0x15, 0x67, 0x64, 0x19, 0x95, 0x5b, 0xd7, 0x44, 0x39, 0xf1, 0x88, 0x8f, 0xa6, 0x26, 0xfa,
		0xa8, 0xf2, 0x5f, 0xf8, 0x68, 0x7a, 0xd8, 0x47, 0xdb, 0xb0, 0x31, 0xd9, 0xfe, 0xf2, 0x7c, 0xfd,
		0xeb, 0x14, 0xac, 0xba, 0x28, 0x51, 0xbd, 0x29, 0xe9, 0xba, 0x0c, 0xb3, 0x02, 0xa9, 0xe4, 0x91,
		0x49, 0x56, 0xf3, 0x44, 0x1e, 0x83, 0x1d, 0xa0, 0xcf, 0x64, 0xfa, 0x2a, 0x39, 0x62, 0x11, 0x93,
		0x1d, 0x0f, 0x4f, 0x31, 0x1a, 0x24, 0x6e, 0xc5, 0x5d, 0xca, 0xd7, 0x77, 0xf4, 0xf2, 0xf3, 0x74,
		0x75, 0x37, 0x18, 0xc9, 0xf1, 0x99, 0xd1, 0x1c, 0x6f, 0xc2, 0x5b, 0xf2, 0x98, 0xc5, 0x9e, 0x89,
		0x91, 0x40, 0x1a, 0xc7, 0x61, 0x5f, 0x67, 0x72, 0xd5, 0xbd, 0x91, 0x2e, 0x65, 0x2e, 0x76, 0xb3,
		0x85, 0xb4, 0x32, 0x8c, 0xf3, 0x57, 0xb9, 0xa7, 0xff, 0x61, 0xc1, 0x7b, 0xc6, 0xa7, 0x2d, 0x1a,
		0xf9, 0xf8, 0x7f, 0x50, 0x20, 0x9c, 0x0d, 0x78, 0x7f, 0x92, 0x49, 0x67, 0x77, 0x75, 0xfd, 0x00,
		0x45, 0x97, 0x45, 0x54, 0xe1, 0x9b, 0x9e, 0x6b, 0x8f, 0x60, 0x2e, 0x40, 0x45, 0x59, 0x28, 0x4d,
		0x97, 0x54, 0x7e, 0x5b, 0x73, 0xe5, 0x21, 0x4f, 0xce, 0x0c, 0x7b, 0xd2, 0x79, 0x17, 0x9c, 0x32,
		0xfb, 0x8d, 0x9b, 0xfe, 0x60, 0xc1, 0xda, 0x33, 0x94, 0xbe, 0x60, 0x87, 0x6f, 0x8a, 0x97, 0x9c,
		0x6f, 0x2a, 0xb0, 0x5e, 0x72, 0x26, 0x93, 0xf5, 0x21, 0xac, 0x9c, 0xf5, 0x7a, 0x3e, 0x8f, 0x8e,
		0x58, 0xdb, 0xbc, 0x58, 0x4d, 0xa9, 0x7d, 0x78, 0xb9, 0x13, 0xb4, 0xce, 0x43, 0xdd, 0x65, 0x2c,
		0x94, 0x93, 0x43, 0x58, 0xb9, 0x68, 0xaa, 0xc7, 0xa2, 0x23, 0x6e, 0xec, 0xbd, 0x77, 0xb9, 0xdd,
		0x76, 0xa3, 0x23, 0x7e, 0xd6, 0x61, 0x0d, 0x89, 0xc9, 0x2b, 0x20, 0x31, 0x46, 0x01, 0x8b, 0xda,
		0x1e, 0xf5, 0x15, 0x3b, 0x65, 0x8a, 0xa1, 0xb4, 0x2b, 0x6b, 0x95, 0x8d, 0xda, 0xd6, 0x46, 0x71,
		0x42, 0x64, 0xea, 0xdb, 0x99, 0x76, 0x5f, 0x93, 0xdf, 0x88, 0x87, 0x84, 0x0c, 0x25, 0xf9, 0x19,
		0x5c, 0xcf, 0x89, 0xfd, 0x0e, 0x0b, 0x03, 0x81, 0x91, 0x3d, 0xad, 0x69, 0x9b, 0x65, 0xb4, 0xad,
		0x54, 0x77, 0xf8, 0xe4, 0xd7, 0xe2, 0x73, 0x4b, 0x02, 0x23, 0xb2, 0x7f, 0x46, 0x9d, 0x57, 0x43,
		0xd3, 0xb0, 0x97, 0x9e, 0xf8, 0x99, 0xd1, 0x1d, 0x22, 0xcd, 0x85, 0xce, 0xd7, 0x15, 0x78, 0xfb,
		0x27, 0xe9, 0xc4, 0x94, 0xbb, 0xef, 0x5b, 0xba, 0xae, 0x1f, 0xc1, 0x8c, 0x1e, 0xdc, 0xcc, 0x2b,
		0xd4, 0x29, 0x65, 0xd2, 0x07, 0x76, 0x33, 0x00, 0xf1, 0x60, 0x59, 0xff, 0xf0, 0x04, 0xfe, 0x02,
		0x7d, 0x95, 0xe6, 0x67, 0xc0, 0xf4, 0xa1, 0xa6, 0x75, 0x3f, 0xfe, 0xdd, 0x42, 0xaa, 0x8c, 0x42,
		0x23, 0x5a, 0x39, 0xc0, 0x7d, 0xfb, 0xa4, 0x40, 0x9a, 0xe6, 0x63, 0xb6, 0x81, 0xcf, 0x23, 0xc9,
		0xa4, 0xc2, 0xc8, 0xef, 0x7b, 0x21, 0x9e, 0x62, 0xa8, 0xdd, 0x3f, 0xae, 0xe3, 0xd7, 0x3b, 0xb4,
		0xce, 0x20, 0x9f, 0xa5, 0x08, 0x77, 0xe9, 0xa4, 0x48, 0xec, 0xfc, 0xd9, 0x82, 0xa5, 0x91, 0x30,
		0x98, 0xbb, 0xf7, 0x09, 0xd4, 0x73, 0xf3, 0x64, 0x12, 0xe6, 0xbd, 0xcd, 0x84, 0x16, 0xc3, 0xd8,
		0x91, 0x02, 0xc8, 0x2e, 0x2c, 0x9e, 0xf7, 0x0f, 0x06, 0x26, 0x58, 0xce, 0x24, 0xbf, 0x60, 0xe0,
		0x2e, 0x9c, 0x9c, 0x7f, 0x74, 0xfe, 0x6d, 0xc1, 0x4a, 0x5e, 0x2d, 0x06, 0x63, 0xe4, 0x84, 0x7c,
		0x19, 0x9a, 0x4b, 0xa7, 0xae, 0x36, 0x97, 0xbe, 0x80, 0xc5, 0x01, 0xf6, 0x6c, 0x38, 0x5e, 0x1c,
		0x33, 0x1c, 0xe7, 0x04, 0xd9, 0x70, 0xac, 0xce, 0x3d, 0xa5, 0x0d, 0x06, 0x8b, 0xfc, 0x30, 0x09,
		0xd0, 0x3b, 0x23, 0x94, 0x8a, 0xaa, 0x24, 0x7b, 0x0b, 0x54, 0xdd, 0x25, 0xb3, 0x9e, 0x93, 0xec,
		0xeb, 0x45, 0xe7, 0x2f, 0x16, 0xd8, 0x17, 0x2d, 0x36, 0xa1, 0xf9, 0x01, 0xcc, 0xc5, 0x3c, 0x0c,
		0x51, 0x48, 0xdb, 0xd2, 0x57, 0xfc, 0x4e, 0x71, 0x54, 0xb4, 0x8e, 0xbe, 0x7e, 0xb9, 0x3e, 0x79,
		0x09, 0xd7, 0x2f, 0x1c, 0x24, 0x73, 0xce, 0xdd, 0x52, 0xdb, 0xb2, 0x63, 0xb9, 0x8b, 0x6a, 0xf8,
		0x98, 0x12, 0x56, 0xb5, 0xad, 0x46, 0xba, 0x47, 0x85, 0xd2, 0xb9, 0x2b, 0xff, 0x87, 0xd1, 0x71,
		0x7e, 0x3d, 0x05, 0xb7, 0xc7, 0xed, 0x6a, 0x3c, 0x74, 0x02, 0xab, 0xa6, 0xbc, 0xf6, 0xcf, 0x39,
		0x3e, 0x1e, 0x28, 0x1a, 0xbf, 0x35, 0x4b, 0xb7, 0x1c, 0xf0, 0xbe, 0x44, 0x45, 0x03, 0xaa, 0xa8,
		0xdb, 0xc8, 0x49, 0x2f, 0x6e, 0x9d, 0x6e, 0x39, 0xe8, 0x25, 0x0b, 0xb7, 0x9c, 0x7a, 0xbd, 0x2d,
		0x73, 0xd2, 0x8b, 0x5b, 0x3a, 0x2b, 0xb0, 0xf4, 0x02, 0x55, 0x2b, 0x4c, 0xa4, 0x32, 0x71, 0xce,
		0xbc, 0xee, 0xfc, 0xca, 0x82, 0xe5, 0xd1, 0x15, 0xe3, 0x99, 0x0e, 0xdc, 0x94, 0x49, 0x1c, 0x73,
		0xa1, 0x30, 0xf0, 0xfc, 0x90, 0xa5, 0xdd, 0xee, 0x29, 0x0a, 0x69, 0xbc, 0x92, 0x06, 0xe2, 0xc3,
		0xe2, 0xf9, 0x25, 0x47, 0xb5, 0x34, 0xe8, 0x0b, 0x83, 0x71, 0x57, 0x64, 0xf1, 0x82, 0xf3, 0xdb,
		0x0a, 0x38, 0x2f, 0x0a, 0x7a, 0xda, 0x4f, 0xb3, 0x4f, 0x69, 0xdf, 0x52, 0xbd, 0xbf, 0x05, 0xf3,
		0x31, 0x6d, 0xa3, 0x27, 0xd9, 0x57, 0xd9, 0xad, 0x9e, 0x71, 0xab, 0xa9, 0x60, 0x9f, 0x7d, 0x85,
		0xe4, 0x7d, 0xb8, 0x16, 0xe1, 0x97, 0x69, 0xd4, 0xda, 0xe8, 0x29, 0x7e, 0x8c, 0x91, 0x99, 0x8e,
		0x16, 0x52, 0xf1, 0x1e, 0x6d, 0xe3, 0x41, 0x2a, 0x24, 0x1f, 0x00, 0xe9, 0x51, 0xa6, 0xbc, 0x23,
		0x2e, 0xbc, 0x08, 0x7b, 0xd9, 0xd0, 0xa0, 0x8b, 0x72, 0xd5, 0xbd, 0x96, 0xae, 0xec, 0x70, 0xf1,
		0x39, 0xf6, 0xf4, 0xb4, 0x40, 0x3c, 0xb8, 0x69, 0xbe, 0x1e, 0x9a, 0xe1, 0xe2, 0x88, 0x85, 0x0a,
		0x45, 0x56, 0x57, 0x66, 0x75, 0x5d, 0x79, 0xb7, 0xd0, 0x1e, 0x0d, 0xdf, 0xd1, 0xca, 0xba, 0xb4,
		0x2c, 0x1b, 0x9a, 0x11, 0x39, 0xb9, 0x0b, 0x0b, 0x7a, 0xda, 0xa0, 0xc2, 0xef, 0xb0, 0x53, 0x9a,
		0x4d, 0xbd, 0x55, 0xb7, 0x9e, 0x0a, 0xb7, 0x8d, 0xcc, 0xf9, 0x97, 0x05, 0x77, 0x4b, 0xa3, 0x61,
		0xf2, 0xe3, 0x11, 0xcc, 0x99, 0x6d, 0x4a, 0x2b, 0x7e, 0x0e, 0xcb, 0x95, 0xc9, 0x8f, 0xa1, 0x26,
		0x68, 0xcf, 0xcb, 0xb1, 0x59, 0xb2, 0x17, 0x5f, 0xe9, 0x67, 0x54, 0xd1, 0xa7, 0x21, 0x3f, 0x74,
		0x41, 0xd0, 0x9e, 0x21, 0x2a, 0x72, 0x7d, 0xa5, 0xc8, 0xf5, 0x0d, 0xa8, 0x66, 0x76, 0x62, 0x60,
		0x2a, 0xe8, 0xe0, 0xd9, 0xe9, 0x43, 0x7d, 0x07, 0xa9, 0x4a, 0x04, 0xee, 0x84, 0xb4, 0x2d, 0x09,
		0x83, 0xad, 0x82, 0x86, 0x8e, 0x86, 0x02, 0x69, 0x90, 0xbe, 0x55, 0xbb, 0x71, 0x88, 0xe9, 0x35,
		0x40, 0x21, 0xb8, 0xf0, 0x30, 0xa2, 0x87, 0x21, 0x66, 0x03, 0x56, 0xd5, 0xbd, 0x7f, 0x21, 0x75,
		0xb6, 0x33, 0x5c, 0x2b, 0x87, 0x3d, 0x4f, 0x51, 0xcf, 0x33, 0xd0, 0xd6, 0x3f, 0xeb, 0x50, 0xcb,
		0x7d, 0xbb, 0xbd, 0xb7, 0x4b, 0x7e, 0x69, 0xc1, 0x72, 0xf1, 0xf0, 0x4c, 0x5e, 0xe3, 0xf3, 0x40,
		0xe3, 0xe1, 0x95, 0x30, 0x26, 0x94, 0x5f, 0x5b, 0xb0, 0x32, 0xe6, 0x73, 0x07, 0x19, 0x43, 0x58,
		0xfa, 0x91, 0xa9, 0xf1, 0xbd, 0xab, 0x81, 0xcc, 0x31, 0xfe, 0x64, 0xc1, 0xda, 0xa4, 0x2f, 0x0a,
		0xe4, 0x87, 0x65, 0xd4, 0x93, 0x3e, 0xc4, 0x34, 0x7e, 0xf4, 0x9a, 0x68, 0x73, 0xc2, 0x34, 0x58,
		0xc5, 0xf3, 0xf7, 0x98, 0x60, 0x95, 0x7e, 0xdc, 0x18, 0x13, 0xac, 0x09, 0x03, 0xfe, 0x1f, 0x2d,
		0xb8, 0x5d, 0x3e, 0xf6, 0x92, 0x27, 0x63, 0x78, 0x2f, 0x31, 0xfe, 0x37, 0x3e, 0x7e, 0x2d, 0xac,
		0x39, 0xdb, 0xef, 0x2c, 0x68, 0x8c, 0x9f, 0x33, 0xc9, 0xa3, 0xe2, 0x57, 0xda, 0xa4, 0xc1, 0xbc,
		0xf1, 0xf8, 0xca, 0x38, 0x73, 0x9e, 0xdf, 0x58, 0x70, 0x73, 0xec, 0xf0, 0x48, 0xbe, 0x5f, 0x5c,
		0x74, 0x26, 0x0c, 0xc0, 0x8d, 0x47, 0x57, 0x85, 0x99, 0xc3, 0x1c, 0xc1, 0xc2, 0x50, 0x03, 0x4d,
		0x4a, 0xfa, 0xfe, 0x91, 0x59, 0xa7, 0x71, 0xef, 0x32, 0xaa, 0x66, 0x1f, 0x0e, 0xd7, 0x47, 0x1b,
		0x42, 0xf2, 0x61, 0xe9, 0x99, 0x47, 0x3a, 0xe5, 0xc6, 0xfd, 0x4b, 0x6a, 0x9f, 0xbb, 0x15, 0xc5,
		0x6d, 0xd6, 0x98, 0x5b, 0x51, 0xda, 0x09, 0x8e, 0xb9, 0x15, 0x13, 0xfa, 0x38, 0x06, 0x8b, 0xc3,
		0x7d, 0x0c, 0x29, 0x76, 0x59, 0x61, 0x1b, 0xd4, 0xf8, 0xe0, 0x52, 0xba, 0x66, 0xab, 0xdf, 0x5b,
		0x70, 0xab, 0xe4, 0x05, 0x49, 0x1e, 0x8f, 0x23, 0x9b, 0xd0, 0xe0, 0x34, 0x3e, 0xba, 0x3a, 0x30,
		0x3b, 0xd2, 0xd3, 0x2f, 0x60, 0xc5, 0xe7, 0xdd, 0x22, 0xf8, 0xd3, 0xea, 0x76, 0xcc, 0xf6, 0x04,
		0x57, 0x7c, 0xcf, 0xfa, 0xf9, 0x66, 0x9b, 0xa9, 0x4e, 0x72, 0xd8, 0xf4, 0x79, 0x77, 0x73, 0xe8,
		0x3f, 0xc5, 0x66, 0x1b, 0xa3, 0xec, 0x8f, 0x50, 0xf3, 0xf7, 0xe2, 0xc7, 0x34, 0x66, 0xa7, 0x0f,
		0x0e, 0x67, 0xb5, 0xec, 0xe1, 0x7f, 0x02, 0x00, 0x00, 0xff, 0xff, 0xff, 0x45, 0x99, 0x6b, 0x6d,
		0x1d, 0x00, 0x00,
	},
	// google/protobuf/duration.proto
	[]byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xe2, 0x92, 0x4b, 0xcf, 0xcf, 0x4f,
		0xcf, 0x49, 0xd5, 0x2f, 0x28, 0xca, 0x2f, 0xc9, 0x4f, 0x2a, 0x4d, 0xd3, 0x4f, 0x29, 0x2d, 0x4a,
		0x2c, 0xc9, 0xcc, 0xcf, 0xd3, 0x03, 0x8b, 0x08, 0xf1, 0x43, 0xe4, 0xf5, 0x60, 0xf2, 0x4a, 0x56,
		0x5c, 0x1c, 0x2e, 0x50, 0x25, 0x42, 0x12, 0x5c, 0xec, 0xc5, 0xa9, 0xc9, 0xf9, 0x79, 0x29, 0xc5,
		0x12, 0x8c, 0x0a, 0x8c, 0x1a, 0xcc, 0x41, 0x30, 0xae, 0x90, 0x08, 0x17, 0x6b, 0x5e, 0x62, 0x5e,
		0x7e, 0xb1, 0x04, 0x93, 0x02, 0xa3, 0x06, 0x6b, 0x10, 0x84, 0xe3, 0xd4, 0xcc, 0xc8, 0x25, 0x9c,
		0x9c, 0x9f, 0xab, 0x87, 0x66, 0xa6, 0x13, 0x2f, 0xcc, 0xc4, 0x00, 0x90, 0x48, 0x00, 0x63, 0x94,
		0x21, 0x54, 0x45, 0x7a, 0x7e, 0x4e, 0x62, 0x5e, 0xba, 0x5e, 0x7e, 0x51, 0x3a, 0xc2, 0x81, 0x25,
		0x95, 0x05, 0xa9, 0xc5, 0xfa, 0xd9, 0x79, 0xf9, 0xe5, 0x79, 0x70, 0xc7, 0x16, 0x24, 0xfd, 0x60,
		0x64, 0x5c, 0xc4, 0xc4, 0xec, 0x1e, 0xe0, 0xb4, 0x8a, 0x49, 0xce, 0x1d, 0xa2, 0x39, 0x00, 0xaa,
		0x43, 0x2f, 0x3c, 0x35, 0x27, 0xc7, 0x1b, 0xa4, 0x3e, 0x04, 0xa4, 0x35, 0x89, 0x0d, 0x6c, 0x94,
		0x31, 0x20, 0x00, 0x00, 0xff, 0xff, 0xef, 0x8a, 0xb4, 0xc3, 0xfb, 0x00, 0x00, 0x00,
	},
	// uber/cadence/api/v1/common.proto
	[]byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xbc, 0x55, 0x4f, 0x6f, 0xdb, 0x36,
		0x14, 0x9f, 0xe2, 0xda, 0x49, 0x9f, 0xdd, 0xd4, 0x63, 0xd6, 0xd4, 0xc9, 0xfe, 0x79, 0x06, 0x86,
		0x66, 0x3b, 0x48, 0x88, 0x7b, 0x29, 0x56, 0x14, 0x83, 0x13, 0x3b, 0xab, 0xda, 0x2d, 0x31, 0x64,
		0x23, 0xc1, 0x76, 0x98, 0x40, 0x4b, 0x4f, 0x2e, 0x67, 0x89, 0x14, 0x28, 0xca, 0x89, 0x6f, 0xfb,
		0x24, 0x3b, 0xec, 0x2b, 0xed, 0x0b, 0x0d, 0x94, 0xe8, 0xd8, 0xee, 0x3c, 0xf4, 0x32, 0xec, 0x46,
		0xbe, 0xdf, 0x9f, 0xf7, 0xa3, 0xf0, 0x48, 0x41, 0x3b, 0x9f, 0xa0, 0x74, 0x02, 0x1a, 0x22, 0x0f,
		0xd0, 0xa1, 0x29, 0x73, 0xe6, 0xa7, 0x4e, 0x20, 0x92, 0x44, 0x70, 0x3b, 0x95, 0x42, 0x09, 0x72,
		0xa0, 0x19, 0xb6, 0x61, 0xd8, 0x34, 0x65, 0xf6, 0xfc, 0xf4, 0xf8, 0x8b, 0xa9, 0x10, 0xd3, 0x18,
		0x9d, 0x82, 0x32, 0xc9, 0x23, 0x27, 0xcc, 0x25, 0x55, 0x6c, 0x29, 0xea, 0xbc, 0x85, 0x8f, 0x6f,
		0x84, 0x9c, 0x45, 0xb1, 0xb8, 0x1d, 0xdc, 0x61, 0x90, 0x6b, 0x88, 0x7c, 0x09, 0xf5, 0x5b, 0x53,
		0xf4, 0x59, 0xd8, 0xb2, 0xda, 0xd6, 0xc9, 0x43, 0x0f, 0x96, 0x25, 0x37, 0x24, 0x4f, 0xa0, 0x26,
		0x73, 0xae, 0xb1, 0x9d, 0x02, 0xab, 0xca, 0x9c, 0xbb, 0x61, 0xa7, 0x03, 0x8d, 0xa5, 0xd9, 0x78,
		0x91, 0x22, 0x21, 0xf0, 0x80, 0xd3, 0x04, 0x8d, 0x41, 0xb1, 0xd6, 0x9c, 0x5e, 0xa0, 0xd8, 0x9c,
		0xa9, 0xc5, 0xbf, 0x72, 0x3e, 0x87, 0xdd, 0x21, 0x5d, 0xc4, 0x82, 0x86, 0x1a, 0x0e, 0xa9, 0xa2,
		0x05, 0xdc, 0xf0, 0x8a, 0x75, 0xe7, 0x25, 0xec, 0x5e, 0x50, 0x16, 0xe7, 0x12, 0xc9, 0x21, 0xd4,
		0x24, 0xd2, 0x4c, 0x70, 0xa3, 0x37, 0x3b, 0xd2, 0x82, 0xdd, 0x10, 0x15, 0x65, 0x71, 0x56, 0x24,
		0x6c, 0x78, 0xcb, 0x6d, 0xe7, 0x0f, 0x0b, 0x1e, 0xfc, 0x84, 0x89, 0x20, 0xaf, 0xa0, 0x16, 0x31,
		0x8c, 0xc3, 0xac, 0x65, 0xb5, 0x2b, 0x27, 0xf5, 0xee, 0xd7, 0xf6, 0x96, 0xef, 0x67, 0x6b, 0xaa,
		0x7d, 0x51, 0xf0, 0x06, 0x5c, 0xc9, 0x85, 0x67, 0x44, 0xc7, 0x37, 0x50, 0x5f, 0x2b, 0x93, 0x26,
		0x54, 0x66, 0xb8, 0x30, 0x29, 0xf4, 0x92, 0x74, 0xa1, 0x3a, 0xa7, 0x71, 0x8e, 0x45, 0x80, 0x7a,
		0xf7, 0xb3, 0xad, 0xf6, 0xe6, 0x98, 0x5e, 0x49, 0xfd, 0x6e, 0xe7, 0x85, 0xd5, 0xf9, 0xd3, 0x82,
		0xda, 0x6b, 0xa4, 0x21, 0x4a, 0xf2, 0xfd, 0x7b, 0x11, 0x9f, 0x6d, 0xf5, 0x28, 0xc9, 0xff, 0x6f,
		0xc8, 0xbf, 0x2c, 0x68, 0x8e, 0x90, 0xca, 0xe0, 0x5d, 0x4f, 0x29, 0xc9, 0x26, 0xb9, 0xc2, 0x8c,
		0xf8, 0xb0, 0xcf, 0x78, 0x88, 0x77, 0x18, 0xfa, 0x1b, 0xb1, 0x5f, 0x6c, 0x75, 0x7d, 0x5f, 0x6e,
		0xbb, 0xa5, 0x76, 0xfd, 0x1c, 0x8f, 0xd8, 0x7a, 0xed, 0xf8, 0x57, 0x20, 0xff, 0x24, 0xfd, 0x87,
		0xa7, 0x8a, 0x60, 0xaf, 0x4f, 0x15, 0x3d, 0x8b, 0xc5, 0x84, 0x5c, 0xc0, 0x23, 0xe4, 0x81, 0x08,
		0x19, 0x9f, 0xfa, 0x6a, 0x91, 0x96, 0x03, 0xba, 0xdf, 0xfd, 0x6a, 0xab, 0xd7, 0xc0, 0x30, 0xf5,
		0x44, 0x7b, 0x0d, 0x5c, 0xdb, 0xdd, 0x0f, 0xf0, 0xce, 0xda, 0x00, 0x0f, 0xcb, 0x4b, 0x87, 0xf2,
		0x1a, 0x65, 0xc6, 0x04, 0x77, 0x79, 0x24, 0x34, 0x91, 0x25, 0x69, 0xbc, 0xbc, 0x08, 0x7a, 0x4d,
		0x9e, 0xc1, 0xe3, 0x08, 0xa9, 0xca, 0x25, 0xfa, 0xf3, 0x92, 0x6a, 0x2e, 0xdc, 0xbe, 0x29, 0x1b,
		0x83, 0xce, 0x5b, 0x78, 0x3a, 0xca, 0xd3, 0x54, 0x48, 0x85, 0xe1, 0x79, 0xcc, 0x90, 0x2b, 0x83,
		0x64, 0xfa, 0xae, 0x4e, 0x85, 0x9f, 0x85, 0x33, 0xe3, 0x5c, 0x9d, 0x8a, 0x51, 0x38, 0x23, 0x47,
		0xb0, 0xf7, 0x1b, 0x9d, 0xd3, 0x02, 0x28, 0x3d, 0x77, 0xf5, 0x7e, 0x14, 0xce, 0x3a, 0xbf, 0x57,
		0xa0, 0xee, 0xa1, 0x92, 0x8b, 0xa1, 0x88, 0x59, 0xb0, 0x20, 0x7d, 0x68, 0x32, 0xce, 0x14, 0xa3,
		0xb1, 0xcf, 0xb8, 0x42, 0x39, 0xa7, 0x65, 0xca, 0x7a, 0xf7, 0xc8, 0x2e, 0x9f, 0x17, 0x7b, 0xf9,
		0xbc, 0xd8, 0x7d, 0xf3, 0xbc, 0x78, 0x8f, 0x8d, 0xc4, 0x35, 0x0a, 0xe2, 0xc0, 0xc1, 0x84, 0x06,
		0x33, 0x11, 0x45, 0x7e, 0x20, 0x30, 0x8a, 0x58, 0xa0, 0x63, 0x16, 0xbd, 0x2d, 0x8f, 0x18, 0xe8,
		0x7c, 0x85, 0xe8, 0xb6, 0x09, 0xbd, 0x63, 0x49, 0x9e, 0xac, 0xda, 0x56, 0x3e, 0xd8, 0xd6, 0x48,
		0xee, 0xdb, 0x7e, 0xb3, 0x72, 0xa1, 0x4a, 0x61, 0x92, 0xaa, 0xac, 0xf5, 0xa0, 0x6d, 0x9d, 0x54,
		0xef, 0xa9, 0x3d, 0x53, 0x26, 0xaf, 0xe0, 0x53, 0x2e, 0xb8, 0x2f, 0xf5, 0xd1, 0xe9, 0x24, 0x46,
		0x1f, 0xa5, 0x14, 0xd2, 0x2f, 0x9f, 0x94, 0xac, 0x55, 0x6d, 0x57, 0x4e, 0x1e, 0x7a, 0x2d, 0x2e,
		0xb8, 0xb7, 0x64, 0x0c, 0x34, 0xc1, 0x2b, 0x71, 0xf2, 0x06, 0x0e, 0xf0, 0x2e, 0x65, 0x65, 0x90,
		0x55, 0xe4, 0xda, 0x87, 0x22, 0x93, 0x95, 0x6a, 0x99, 0xfa, 0xdb, 0x5b, 0x68, 0xac, 0xcf, 0x14,
		0x39, 0x82, 0x27, 0x83, 0xcb, 0xf3, 0xab, 0xbe, 0x7b, 0xf9, 0x83, 0x3f, 0xfe, 0x79, 0x38, 0xf0,
		0xdd, 0xcb, 0xeb, 0xde, 0x8f, 0x6e, 0xbf, 0xf9, 0x11, 0x39, 0x86, 0xc3, 0x4d, 0x68, 0xfc, 0xda,
		0x73, 0x2f, 0xc6, 0xde, 0x4d, 0xd3, 0x22, 0x87, 0x40, 0x36, 0xb1, 0x37, 0xa3, 0xab, 0xcb, 0xe6,
		0x0e, 0x69, 0xc1, 0x27, 0x9b, 0xf5, 0xa1, 0x77, 0x35, 0xbe, 0x7a, 0xde, 0xac, 0x9c, 0x5d, 0xc3,
		0xd3, 0x40, 0x24, 0xdb, 0x86, 0xfc, 0x6c, 0xaf, 0x97, 0xb2, 0xa1, 0x4e, 0x3f, 0xb4, 0x7e, 0x71,
		0xa6, 0x4c, 0xbd, 0xcb, 0x27, 0x76, 0x20, 0x12, 0x67, 0xe3, 0xc7, 0x64, 0x4f, 0x91, 0x97, 0x3f,
		0x1b, 0xf3, 0x8f, 0x7a, 0x49, 0x53, 0x36, 0x3f, 0x9d, 0xd4, 0x8a, 0xda, 0xf3, 0xbf, 0x03, 0x00,
		0x00, 0xff, 0xff, 0xdc, 0x8c, 0x77, 0x9a, 0xc7, 0x06, 0x00, 0x00,
	},
	// uber/cadence/api/v1/history.proto
	[]byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xec, 0x5c, 0x5f, 0x6c, 0x1c, 0x57,
		0xd5, 0xef, 0xec, 0xda, 0xbb, 0xde, 0xb3, 0x8e, 0x63, 0xdf, 0x24, 0x8e, 0x9d, 0xbf, 0xce, 0x24,
		0x4d, 0x5c, 0xc7, 0x59, 0x27, 0x4e, 0x9a, 0x7c, 0x69, 0xbe, 0xb6, 0x38, 0x8e, 0xad, 0xae, 0x64,
		0x92, 0x68, 0xe2, 0xa4, 0x80, 0x90, 0x96, 0xf1, 0xcc, 0x75, 0x3c, 0xf2, 0xee, 0xcc, 0x76, 0x66,
		0xd6, 0x1b, 0x23, 0xf1, 0xc4, 0x03, 0x12, 0x6a, 0x05, 0x55, 0x85, 0x44, 0x05, 0x08, 0x84, 0x04,
		0x6a, 0x11, 0x52, 0x11, 0x08, 0x01, 0xe2, 0x05, 0x90, 0x10, 0x48, 0xa0, 0xc2, 0x13, 0x2f, 0x3c,
		0xc0, 0x03, 0x0f, 0xf4, 0x8d, 0x07, 0xca, 0x1b, 0x12, 0x9a, 0x3b, 0x77, 0x76, 0x77, 0x66, 0xee,
		0x9d, 0xb9, 0xb3, 0xde, 0xb4, 0xa0, 0xe6, 0xcd, 0x73, 0xe7, 0xdc, 0x33, 0xbf, 0x7b, 0xee, 0x39,
		0xe7, 0x9e, 0x7b, 0xce, 0x59, 0xc3, 0xa9, 0xd6, 0x06, 0xb6, 0x17, 0x34, 0x55, 0xc7, 0xa6, 0x86,
		0x17, 0xd4, 0xa6, 0xb1, 0xb0, 0x73, 0x69, 0x61, 0xcb, 0x70, 0x5c, 0xcb, 0xde, 0xad, 0x34, 0x6d,
		0xcb, 0xb5, 0xd0, 0x01, 0x8f, 0xa4, 0x42, 0x49, 0x2a, 0x6a, 0xd3, 0xa8, 0xec, 0x5c, 0x3a, 0x72,
		0xe2, 0xa1, 0x65, 0x3d, 0xac, 0xe3, 0x05, 0x42, 0xb2, 0xd1, 0xda, 0x5c, 0xd0, 0x5b, 0xb6, 0xea,
		0x1a, 0x96, 0xe9, 0x4f, 0x3a, 0x72, 0x32, 0xfa, 0xde, 0x35, 0x1a, 0xd8, 0x71, 0xd5, 0x46, 0x93,
		0x12, 0xcc, 0xb0, 0x3e, 0xac, 0x59, 0x8d, 0x46, 0x87, 0x85, 0xcc, 0xa2, 0x70, 0x55, 0x67, 0xbb,
		0x6e, 0x38, 0x6e, 0x12, 0x4d, 0xdb, 0xb2, 0xb7, 0x37, 0xeb, 0x56, 0xdb, 0xa7, 0x91, 0x6f, 0x41,
		0xf1, 0x25, 0x7f, 0x41, 0xe8, 0x3a, 0x14, 0xf0, 0x0e, 0x36, 0x5d, 0x67, 0x4a, 0x9a, 0xc9, 0xcf,
		0x96, 0x17, 0x4f, 0x55, 0x18, 0x6b, 0xab, 0x50, 0xea, 0x15, 0x8f, 0x52, 0xa1, 0x13, 0xe4, 0xf7,
		0xae, 0xc1, 0x68, 0xef, 0x0b, 0x34, 0x0d, 0x23, 0xe4, 0x55, 0xcd, 0xd0, 0xa7, 0xa4, 0x19, 0x69,
		0x36, 0xaf, 0x14, 0xc9, 0x73, 0x55, 0x47, 0xd7, 0x01, 0xfc, 0x57, 0xde, 0xa2, 0xa7, 0x72, 0x33,
		0xd2, 0x6c, 0x79, 0xf1, 0x48, 0xc5, 0x97, 0x48, 0x25, 0x90, 0x48, 0x65, 0x3d, 0x90, 0x88, 0x52,
		0x22, 0xd4, 0xde, 0x33, 0x9a, 0x82, 0xe2, 0x0e, 0xb6, 0x1d, 0xc3, 0x32, 0xa7, 0xf2, 0x3e, 0x53,
		0xfa, 0x88, 0x0e, 0x43, 0xd1, 0x5b, 0xbc, 0xf7, 0xb9, 0x21, 0xf2, 0xa6, 0xe0, 0x3d, 0x56, 0x75,
		0xf4, 0x75, 0x09, 0xce, 0x07, 0x4b, 0xae, 0xe1, 0x47, 0x58, 0x6b, 0x79, 0xfb, 0x50, 0x73, 0x5c,
		0xd5, 0x76, 0xb1, 0x5e, 0xf3, 0x91, 0xa8, 0xae, 0x6b, 0x1b, 0x1b, 0x2d, 0x17, 0x3b, 0x53, 0xc3,
		0x04, 0xcf, 0xff, 0x33, 0x97, 0xfe, 0x32, 0xe5, 0xb3, 0x12, 0xb0, 0xb9, 0xe7, 0x73, 0x21, 0x4b,
		0x5e, 0xea, 0xf0, 0x78, 0xe9, 0x29, 0xe5, 0x5c, 0x5b, 0x8c, 0x14, 0x7d, 0x5b, 0x82, 0x0b, 0x0c,
		0x78, 0x9a, 0xd5, 0x68, 0xd6, 0x31, 0x13, 0x60, 0x81, 0x00, 0x7c, 0x41, 0x0c, 0xe0, 0x72, 0xc0,
		0x27, 0x0e, 0xf1, 0x99, 0xb6, 0x28, 0x31, 0x7a, 0x53, 0x82, 0x39, 0x06, 0xc8, 0x4d, 0xd5, 0xa8,
		0xb3, 0x10, 0x16, 0x09, 0xc2, 0x1b, 0x62, 0x08, 0x57, 0x09, 0x93, 0x38, 0xbc, 0xb3, 0x6d, 0x21,
		0x4a, 0xf4, 0x2d, 0xb6, 0x00, 0x3d, 0xdd, 0xd2, 0x6b, 0x56, 0xcb, 0x8d, 0xc3, 0x1b, 0x21, 0xf0,
		0x9e, 0x17, 0x83, 0xe7, 0xa9, 0x9d, 0x7e, 0xa7, 0xe5, 0xc6, 0x01, 0xce, 0xb6, 0x05, 0x69, 0xd1,
		0x1b, 0x12, 0xcc, 0xea, 0x58, 0x33, 0x1c, 0x02, 0xcc, 0xd3, 0x52, 0x47, 0xdb, 0xc2, 0x7a, 0x8b,
		0x29, 0xbc, 0x12, 0x41, 0x77, 0x9d, 0x89, 0xee, 0x16, 0x65, 0xb2, 0xae, 0x3a, 0xdb, 0xf7, 0x02,
		0x16, 0x71, 0x64, 0x67, 0x74, 0x01, 0x3a, 0xf4, 0x9a, 0x04, 0x67, 0x23, 0xa8, 0x78, 0x36, 0x01,
		0x04, 0xd3, 0xb5, 0x74, 0x4c, 0x3c, 0x73, 0x90, 0xf5, 0x54, 0x2a, 0x86, 0x94, 0x12, 0x8c, 0xa0,
		0x2c, 0x28, 0xa5, 0x04, 0xfd, 0x0f, 0x49, 0x89, 0xab, 0xfa, 0xaf, 0xc7, 0x50, 0x25, 0x68, 0xd6,
		0x28, 0x41, 0xf5, 0x7f, 0xa9, 0xa8, 0xf8, 0x4a, 0x75, 0x5a, 0x4f, 0x27, 0x43, 0x5f, 0x94, 0xe0,
		0xe9, 0x30, 0x26, 0x9e, 0x25, 0xee, 0x23, 0x80, 0xae, 0xa6, 0x02, 0xe2, 0x19, 0xe1, 0x29, 0x3d,
		0x8d, 0x88, 0x6c, 0x9b, 0xaa, 0xb9, 0xc6, 0x8e, 0xe1, 0xee, 0xa6, 0x2a, 0xf7, 0x58, 0xc2, 0xb6,
		0x2d, 0x51, 0x26, 0x69, 0xca, 0xad, 0x0a, 0xd0, 0x11, 0xe5, 0x8e, 0xa0, 0xe2, 0x29, 0xf7, 0xfe,
		0x04, 0xe5, 0x0e, 0x61, 0xe2, 0x2a, 0xb7, 0x9a, 0x4a, 0xc5, 0x90, 0x52, 0x82, 0x72, 0x8f, 0x0b,
		0x4a, 0x29, 0x49, 0xb9, 0x55, 0x01, 0x3a, 0xa2, 0x48, 0x61, 0x54, 0x3c, 0x45, 0x9a, 0x48, 0x50,
		0xa4, 0x5e, 0x48, 0x5c, 0x45, 0x52, 0xd3, 0x88, 0x88, 0xa5, 0x85, 0xc1, 0x24, 0x58, 0x1a, 0x4a,
		0xb0, 0xb4, 0x5e, 0x3c, 0x09, 0x96, 0xa6, 0xa6, 0x93, 0xa1, 0x36, 0x9c, 0xf0, 0x40, 0xd8, 0x7c,
		0xed, 0x39, 0x40, 0x80, 0x5c, 0x64, 0x02, 0xf1, 0xb8, 0xda, 0x5c, 0xb5, 0x39, 0xea, 0xf2, 0x5f,
		0xa3, 0x57, 0xe0, 0x98, 0xff, 0xe1, 0x4d, 0xc3, 0x66, 0x7d, 0xf6, 0x20, 0xf9, 0x6c, 0x85, 0xff,
		0xd9, 0x55, 0x6f, 0x5e, 0xfc, 0xa3, 0xd3, 0x2e, 0xef, 0x25, 0xfa, 0xae, 0x04, 0x0b, 0x11, 0x15,
		0x55, 0x4d, 0x0d, 0xd7, 0x6b, 0x36, 0x7e, 0xa5, 0x85, 0x1d, 0xe6, 0xea, 0x0f, 0x11, 0x18, 0x2f,
		0xa6, 0x6b, 0x2a, 0xe1, 0xa4, 0x04, 0x8c, 0xe2, 0xb8, 0xe6, 0x54, 0x61, 0x6a, 0xf4, 0x23, 0x09,
		0xae, 0x50, 0x4c, 0x01, 0x44, 0x31, 0x25, 0x9e, 0x24, 0x68, 0x97, 0x99, 0x68, 0xe9, 0xd7, 0xfc,
		0x4f, 0x8b, 0x68, 0x74, 0xc5, 0xce, 0x34, 0x03, 0x7d, 0x59, 0x82, 0x73, 0x2c, 0xf1, 0xb2, 0x80,
		0x1e, 0x16, 0xd4, 0xee, 0x65, 0xca, 0x21, 0x45, 0xbb, 0x39, 0x64, 0xe8, 0xb3, 0x70, 0xd2, 0x57,
		0x32, 0x3e, 0x92, 0x29, 0x82, 0xe4, 0x12, 0x5f, 0xcf, 0xf8, 0x10, 0x7c, 0x05, 0xe6, 0x7d, 0xfb,
		0x0b, 0x12, 0x9c, 0xa1, 0x9b, 0x47, 0x15, 0x9d, 0xb3, 0x69, 0xd3, 0x04, 0xc1, 0xb3, 0x4c, 0x04,
		0x3e, 0x73, 0x5f, 0xdf, 0x39, 0xdb, 0x34, 0xa3, 0xa5, 0xd0, 0xa0, 0xcf, 0xc1, 0x4c, 0x43, 0xb5,
		0xb7, 0xb1, 0x5d, 0xb3, 0xb1, 0x66, 0xd9, 0x3a, 0x0b, 0xc4, 0x11, 0x02, 0x62, 0x91, 0x09, 0xe2,
		0xe3, 0x64, 0xb2, 0x42, 0xe7, 0xc6, 0x11, 0x1c, 0x6f, 0x24, 0x11, 0xa0, 0x6f, 0x4a, 0x30, 0xcf,
		0xba, 0x9f, 0x18, 0x0f, 0x4d, 0x95, 0x29, 0x90, 0xa3, 0x59, 0xc2, 0xd7, 0x7b, 0x94, 0x8d, 0x48,
		0xf8, 0xca, 0xa1, 0x45, 0xdf, 0x91, 0xa0, 0xc2, 0x8a, 0xb0, 0xb1, 0xdd, 0x30, 0x4c, 0x95, 0xe9,
		0x17, 0x8e, 0x25, 0xf8, 0x85, 0x78, 0x88, 0xdd, 0x61, 0xc4, 0xf0, 0x0b, 0x6d, 0x61, 0x6a, 0xf4,
		0x63, 0x09, 0xae, 0xb0, 0xae, 0x52, 0xa9, 0x5e, 0xec, 0x38, 0x41, 0x7b, 0x4b, 0xf0, 0x46, 0x95,
		0xe6, 0xca, 0x16, 0xda, 0xd9, 0xa6, 0xf0, 0x34, 0x80, 0x6f, 0x94, 0x27, 0xb2, 0x68, 0x00, 0xdf,
		0x40, 0x67, 0xdb, 0x82, 0xb4, 0xe8, 0x6f, 0x12, 0xac, 0x44, 0x3c, 0x2e, 0x7e, 0xe4, 0x62, 0xdb,
		0x54, 0xeb, 0x35, 0x06, 0x72, 0xc3, 0x34, 0x5c, 0x83, 0xad, 0x18, 0x27, 0x09, 0xf4, 0x7b, 0xe9,
		0x2e, 0x78, 0x85, 0xf2, 0x8f, 0xad, 0xa7, 0x1a, 0x30, 0x8f, 0x2f, 0xe8, 0x05, 0x7b, 0x4f, 0x1c,
		0xd0, 0x9f, 0x25, 0xb8, 0x99, 0x61, 0x99, 0x3c, 0x8f, 0x35, 0x43, 0xd6, 0x78, 0x77, 0x0f, 0x6b,
		0xe4, 0x39, 0xb3, 0x1b, 0x76, 0xff, 0xd3, 0xd1, 0xbb, 0x12, 0x3c, 0x9f, 0xb4, 0x9c, 0x74, 0x3b,
		0x39, 0x45, 0x16, 0xb6, 0xc6, 0x5c, 0x18, 0x17, 0x4c, 0xaa, 0xbd, 0x5c, 0xc3, 0xfd, 0x4d, 0x25,
		0x71, 0x00, 0x33, 0x75, 0x62, 0xba, 0x86, 0xd9, 0xc2, 0x7a, 0x4d, 0x75, 0x6a, 0x26, 0x6e, 0xc7,
		0xd7, 0x21, 0x27, 0xc4, 0x01, 0x8c, 0x0c, 0x0a, 0x65, 0xb7, 0xe4, 0xdc, 0xc6, 0x6d, 0x46, 0x1c,
		0xd0, 0xce, 0x34, 0x03, 0xfd, 0x4a, 0x82, 0xeb, 0x24, 0x9a, 0xac, 0x69, 0x5b, 0x46, 0x5d, 0xcf,
		0x68, 0x3f, 0xa7, 0x09, 0xf4, 0x97, 0x98, 0xd0, 0x49, 0x28, 0xb9, 0xec, 0x31, 0xcd, 0x62, 0x34,
		0x97, 0x9d, 0xec, 0xd3, 0xd0, 0xcf, 0x24, 0xb8, 0x9a, 0xb2, 0x08, 0x9e, 0x75, 0x9c, 0x21, 0x2b,
		0x58, 0xc9, 0xba, 0x02, 0x9e, 0x49, 0x5c, 0x74, 0x32, 0xce, 0x41, 0xdf, 0x97, 0xe0, 0x12, 0x17,
		0x35, 0x37, 0xce, 0x7f, 0x9a, 0xc0, 0x5e, 0x62, 0x87, 0x21, 0xcc, 0xaf, 0x73, 0x03, 0xff, 0x79,
		0x2d, 0x03, 0x3d, 0xfa, 0xa1, 0x04, 0x97, 0xb9, 0x70, 0x13, 0x2e, 0x91, 0x67, 0x13, 0x94, 0x9c,
		0x0d, 0x38, 0xe1, 0x3a, 0x59, 0xd1, 0x32, 0xcd, 0x40, 0x6f, 0x4b, 0x70, 0x31, 0xb3, 0x66, 0x9c,
		0x23, 0x88, 0x3f, 0x96, 0x01, 0x31, 0x4f, 0x29, 0xce, 0x6b, 0x19, 0xf4, 0xe1, 0x1d, 0x09, 0x16,
		0xf9, 0x02, 0xe6, 0x1e, 0xc2, 0xb3, 0x04, 0xed, 0xcd, 0x2c, 0xf2, 0xe5, 0x9e, 0xc4, 0x17, 0xb4,
		0x2c, 0x13, 0xd0, 0x0f, 0x92, 0x54, 0x22, 0xe1, 0xd2, 0xfc, 0x4c, 0x66, 0xc8, 0xfc, 0xeb, 0x33,
		0x07, 0x32, 0xef, 0x22, 0xed, 0xc5, 0x66, 0x7c, 0xc8, 0x09, 0x91, 0xe4, 0x5c, 0x42, 0x6c, 0xc6,
		0xc1, 0x9c, 0x10, 0x4e, 0x2e, 0x68, 0xd9, 0xa6, 0x90, 0x43, 0xd3, 0x0f, 0xc5, 0xfb, 0x8d, 0x78,
		0xce, 0x27, 0x1c, 0x9a, 0x7e, 0xc4, 0xdd, 0x4f, 0xa8, 0x73, 0xcd, 0xe9, 0x6f, 0x2a, 0xfa, 0xb5,
		0x04, 0xcf, 0x09, 0x2c, 0x88, 0x67, 0xa3, 0xf3, 0x64, 0x35, 0xd5, 0x7e, 0x56, 0xc3, 0x33, 0xd6,
		0x2b, 0x4e, 0x1f, 0xf3, 0xd0, 0x4f, 0x25, 0x78, 0x36, 0x69, 0x01, 0xfc, 0xfb, 0xd3, 0x85, 0x84,
		0x03, 0x88, 0x0b, 0x82, 0x7f, 0x8f, 0xba, 0x88, 0x33, 0xce, 0x21, 0x0e, 0xa7, 0xd5, 0x74, 0xb0,
		0xed, 0x76, 0x81, 0x3b, 0x58, 0xb5, 0xb5, 0xad, 0x1e, 0x98, 0x71, 0xdc, 0x95, 0x04, 0xeb, 0xbd,
		0x4f, 0xd8, 0x05, 0x08, 0xee, 0x11, 0x66, 0xdd, 0x2f, 0x32, 0xac, 0xb7, 0x95, 0x65, 0xc2, 0xcd,
		0x51, 0x80, 0x2e, 0x10, 0xf9, 0xaf, 0x65, 0x38, 0x27, 0x7a, 0x7a, 0xad, 0xc2, 0xbe, 0xce, 0x1a,
		0xdd, 0xdd, 0x26, 0x26, 0xb5, 0x40, 0x5e, 0x65, 0x31, 0x60, 0xba, 0xbe, 0xdb, 0xc4, 0xca, 0x68,
		0xbb, 0xe7, 0x09, 0x7d, 0x1a, 0x0e, 0x35, 0x55, 0xdb, 0x93, 0x48, 0xaf, 0xd1, 0x6d, 0x5a, 0xb4,
		0x7c, 0x38, 0xcb, 0xe4, 0x77, 0x97, 0xcc, 0xe8, 0xb1, 0x89, 0x4d, 0x4b, 0x39, 0xd0, 0x8c, 0x0f,
		0xa2, 0xe7, 0xa0, 0x44, 0x32, 0x32, 0x75, 0xc3, 0x71, 0x49, 0x61, 0xb1, 0xbc, 0x78, 0x9c, 0x9d,
		0xf2, 0x50, 0x9d, 0xed, 0x35, 0xc3, 0x71, 0x95, 0x11, 0x97, 0xfe, 0x85, 0x16, 0x61, 0xd8, 0x30,
		0x9b, 0x2d, 0x97, 0x94, 0x1d, 0xcb, 0x8b, 0xc7, 0x38, 0x48, 0x76, 0xeb, 0x96, 0xaa, 0x2b, 0x3e,
		0x29, 0x52, 0x61, 0x26, 0x12, 0x72, 0xd4, 0x5c, 0xab, 0xa6, 0xd5, 0x2d, 0x07, 0x13, 0xff, 0x6d,
		0xb5, 0x5c, 0x5a, 0x87, 0x9c, 0x8e, 0xd5, 0x45, 0x6f, 0xd1, 0x4a, 0xb2, 0x72, 0x0c, 0x87, 0x64,
		0xbf, 0x6e, 0x2d, 0x7b, 0xf3, 0xd7, 0xfd, 0xe9, 0xe8, 0x65, 0x38, 0xda, 0x4d, 0x7b, 0xc7, 0xb9,
		0x17, 0xd2, 0xb8, 0x1f, 0x76, 0x83, 0x64, 0x76, 0x84, 0xf1, 0x0d, 0x38, 0xd2, 0x8d, 0xb0, 0xbb,
		0xab, 0xb0, 0x5b, 0x66, 0xcd, 0xd0, 0x49, 0xe9, 0xaf, 0xa4, 0x1c, 0xee, 0x50, 0x74, 0xe4, 0xac,
		0xb4, 0xcc, 0xaa, 0x8e, 0xaa, 0x50, 0xa2, 0xae, 0xd2, 0xb2, 0x49, 0x1d, 0x6e, 0x6c, 0xf1, 0x3c,
		0xdb, 0xb5, 0x53, 0x06, 0x24, 0x84, 0xae, 0x06, 0x53, 0x94, 0xee, 0x6c, 0x54, 0x85, 0x89, 0x2e,
		0x0e, 0xcf, 0x5d, 0xb5, 0x6c, 0x4c, 0x8b, 0x67, 0xec, 0x3d, 0x58, 0xf5, 0x69, 0x94, 0xf1, 0xce,
		0x34, 0x3a, 0x82, 0x14, 0x98, 0xac, 0xab, 0xde, 0x9d, 0xcf, 0x0f, 0x67, 0xc8, 0x72, 0xb0, 0xd3,
		0xaa, 0xbb, 0xb4, 0xf0, 0x95, 0xbc, 0xa7, 0x07, 0xbd, 0xb9, 0xcb, 0x9d, 0xa9, 0x0a, 0x99, 0x89,
		0xae, 0xc3, 0xb4, 0x65, 0x1b, 0x0f, 0x0d, 0xdf, 0xd1, 0x46, 0xa4, 0x54, 0x26, 0x52, 0x9a, 0x0c,
		0x08, 0x22, 0x42, 0x3a, 0x02, 0x23, 0x86, 0x8e, 0x4d, 0xd7, 0x70, 0x77, 0x49, 0x45, 0xa9, 0xa4,
		0x74, 0x9e, 0xd1, 0x65, 0x98, 0xdc, 0x34, 0x6c, 0xc7, 0x8d, 0xf3, 0xdc, 0x47, 0x28, 0x0f, 0x90,
		0xb7, 0x11, 0x86, 0xcb, 0x30, 0x6a, 0x63, 0xd7, 0xde, 0xad, 0x35, 0xad, 0xba, 0xa1, 0xed, 0xd2,
		0x2a, 0xcc, 0x0c, 0xe7, 0x82, 0xea, 0xda, 0xbb, 0x77, 0x09, 0x9d, 0x52, 0xb6, 0xbb, 0x0f, 0x68,
		0x0a, 0x8a, 0xaa, 0xeb, 0xe2, 0x46, 0xd3, 0x25, 0x15, 0x93, 0x61, 0x25, 0x78, 0x44, 0xcb, 0xb0,
		0x1f, 0x3f, 0x6a, 0x1a, 0xbe, 0xe2, 0xf8, 0x45, 0xfd, 0xf1, 0xd4, 0xa2, 0xfe, 0x58, 0x77, 0x0a,
		0xa9, 0xec, 0x9f, 0x86, 0x7d, 0x9a, 0xed, 0x59, 0x03, 0xad, 0xe8, 0x90, 0x8a, 0x43, 0x49, 0x19,
		0xf5, 0x06, 0x83, 0x2a, 0x0f, 0xfa, 0x04, 0x1c, 0xf5, 0x57, 0x1f, 0xae, 0x7e, 0x6d, 0xa8, 0xda,
		0xb6, 0xb5, 0xb9, 0x49, 0x8b, 0x02, 0x09, 0x4a, 0x3d, 0x45, 0x66, 0xf7, 0x16, 0xbe, 0x6e, 0xfa,
		0x53, 0xd1, 0x05, 0x18, 0x6a, 0xe0, 0x86, 0x45, 0xd3, 0xf9, 0xd3, 0xec, 0x44, 0x1f, 0x6e, 0x58,
		0x0a, 0x21, 0x43, 0x0a, 0x4c, 0xc4, 0x3c, 0x36, 0xcd, 0xc9, 0x3f, 0xcd, 0x3e, 0x1b, 0x23, 0x1e,
		0x56, 0x19, 0x77, 0x22, 0x23, 0xe8, 0x3e, 0x4c, 0x36, 0x6d, 0xbc, 0x53, 0x53, 0x5b, 0xae, 0xe5,
		0xe9, 0x1f, 0x76, 0x6b, 0x4d, 0xcb, 0x30, 0xdd, 0x20, 0xcb, 0xce, 0xdb, 0x2f, 0x07, 0xbb, 0x77,
		0x09, 0x9d, 0x72, 0xc0, 0x9b, 0xbf, 0xd4, 0x72, 0xad, 0x9e, 0x41, 0x74, 0x19, 0x0a, 0x5b, 0x58,
		0xd5, 0xb1, 0x4d, 0xd3, 0xdf, 0x47, 0xd9, 0x4d, 0x1d, 0x84, 0x44, 0xa1, 0xa4, 0xf2, 0xdb, 0x12,
		0x3c, 0x23, 0x1e, 0xed, 0x5f, 0x81, 0x02, 0xb5, 0x17, 0x49, 0xc0, 0x5e, 0x28, 0x2d, 0x5a, 0x85,
		0x99, 0xe4, 0x72, 0xaf, 0xa1, 0x13, 0xef, 0x9e, 0x57, 0x8e, 0xf1, 0x2b, 0xb5, 0x55, 0x5d, 0x7e,
		0x4b, 0x82, 0xb3, 0x82, 0x41, 0xc3, 0x55, 0x28, 0x06, 0x9e, 0x42, 0x12, 0xf0, 0x14, 0x01, 0xf1,
		0xc0, 0xa0, 0x5a, 0x30, 0x2b, 0x1c, 0x31, 0x2f, 0xc3, 0x28, 0x75, 0xd6, 0xdd, 0x83, 0x73, 0x8c,
		0xa3, 0x04, 0xd4, 0x37, 0x93, 0x73, 0xb3, 0xec, 0x76, 0x1f, 0xe4, 0xdf, 0x4b, 0x70, 0x46, 0xa4,
		0x69, 0x20, 0x7c, 0x02, 0x4a, 0xd9, 0x4e, 0xc0, 0xdb, 0x30, 0xc9, 0x39, 0x65, 0x72, 0x69, 0x06,
		0x79, 0xc0, 0x61, 0x9c, 0x30, 0x3d, 0x9e, 0x26, 0x1f, 0xf2, 0x34, 0xf2, 0x6b, 0x12, 0xc8, 0xe9,
		0xfd, 0x06, 0x68, 0x1e, 0x50, 0xb4, 0x06, 0xdd, 0xe9, 0x42, 0x1a, 0x77, 0x42, 0x22, 0x88, 0xb8,
		0xdb, 0x5c, 0xc4, 0xdd, 0x1e, 0x07, 0x08, 0x12, 0x82, 0x86, 0x4e, 0xd0, 0x94, 0x94, 0x12, 0x1d,
		0xa9, 0xea, 0xf2, 0x3f, 0x22, 0xe2, 0xe5, 0x5a, 0x48, 0x36, 0x44, 0xb3, 0x30, 0x1e, 0xce, 0x43,
		0x74, 0xd4, 0x6b, 0xcc, 0xe9, 0x59, 0x71, 0x04, 0x7b, 0x3e, 0x82, 0xfd, 0x1c, 0xec, 0xdf, 0x30,
		0x4c, 0xd5, 0xde, 0xad, 0x69, 0x5b, 0x58, 0xdb, 0x76, 0x5a, 0x0d, 0x12, 0xa2, 0x94, 0x94, 0x31,
		0x7f, 0x78, 0x99, 0x8e, 0xa2, 0xf3, 0x30, 0x11, 0xce, 0x9e, 0xe1, 0x47, 0x7e, 0xf8, 0x31, 0xaa,
		0x8c, 0xe3, 0xde, 0xa4, 0x16, 0x7e, 0xe4, 0xca, 0xaf, 0xe6, 0xe1, 0xb4, 0x40, 0x2b, 0xc3, 0x63,
		0x5b, 0x71, 0xd4, 0x2c, 0xf2, 0x7d, 0x98, 0x05, 0x3a, 0x01, 0xe5, 0x0d, 0xd5, 0xc1, 0xc1, 0xd1,
		0xe9, 0x8b, 0xa5, 0xe4, 0x0d, 0xf9, 0x07, 0xe6, 0x31, 0x00, 0x13, 0xb7, 0x83, 0xd7, 0xc3, 0xbe,
		0x60, 0x4d, 0xdc, 0xf6, 0xdf, 0xce, 0x03, 0xda, 0xb4, 0xec, 0x6d, 0x8a, 0x34, 0xe8, 0x47, 0x2b,
		0xf8, 0x4b, 0xf3, 0xde, 0x10, 0xac, 0x0f, 0x68, 0x63, 0xda, 0xa4, 0xe7, 0x1c, 0x55, 0xc7, 0x32,
		0x69, 0x6c, 0x44, 0x9f, 0xd0, 0x2d, 0x18, 0xd6, 0xd4, 0x96, 0x83, 0x69, 0x18, 0x54, 0x11, 0x6e,
		0x1a, 0x59, 0xf6, 0x66, 0x29, 0xfe, 0x64, 0xf9, 0xad, 0x3c, 0x9c, 0x4a, 0x6d, 0xe4, 0x78, 0x6c,
		0x9b, 0x71, 0x33, 0x58, 0x83, 0xbf, 0x0b, 0xf3, 0x82, 0x7d, 0x26, 0xbd, 0x2b, 0xe8, 0xf5, 0xc9,
		0x43, 0x59, 0x7c, 0x72, 0xaf, 0xea, 0x0f, 0x47, 0x54, 0x3f, 0xb2, 0xbf, 0x85, 0xe4, 0xfd, 0x2d,
		0x0a, 0xed, 0xef, 0x08, 0x67, 0x7f, 0x19, 0x66, 0x56, 0x62, 0x99, 0x99, 0xfc, 0x8d, 0x02, 0x9c,
		0x11, 0xe9, 0x71, 0x41, 0x27, 0xa1, 0xdc, 0x29, 0x14, 0xd3, 0x6d, 0x2a, 0x29, 0x10, 0x0c, 0x55,
		0x75, 0xef, 0x52, 0xd5, 0xad, 0x24, 0x7b, 0x46, 0x90, 0x4b, 0xb8, 0x54, 0x75, 0x3e, 0x49, 0x2e,
		0x55, 0x6a, 0xcf, 0x93, 0xa7, 0x9a, 0xba, 0xd5, 0x50, 0x0d, 0x93, 0xfa, 0x0e, 0xfa, 0x14, 0x3e,
		0x0c, 0x86, 0xfa, 0xbc, 0x0e, 0x15, 0xc4, 0xaf, 0x43, 0xeb, 0x30, 0x1d, 0x28, 0x61, 0xfc, 0x0c,
		0x29, 0xa6, 0x9d, 0x21, 0x93, 0xc1, 0xdc, 0xc8, 0x31, 0x12, 0xe1, 0x4a, 0x8f, 0x28, 0xca, 0x75,
		0x24, 0x03, 0x57, 0xff, 0x16, 0x44, 0xb9, 0xf2, 0x0f, 0xbb, 0x52, 0x5f, 0x87, 0xdd, 0x2a, 0x4c,
		0x6c, 0x61, 0xd5, 0x76, 0x37, 0xb0, 0xda, 0x45, 0x07, 0x69, 0xac, 0xc6, 0x3b, 0x73, 0xba, 0x7c,
		0xd2, 0x43, 0x94, 0x72, 0x7a, 0x88, 0x12, 0xbb, 0x2b, 0x8c, 0xf6, 0x73, 0x57, 0xe8, 0xc6, 0x9c,
		0xfb, 0xc4, 0x63, 0xce, 0xbf, 0x4b, 0x20, 0xa7, 0xf7, 0x5b, 0x7d, 0x60, 0x87, 0x7b, 0x6f, 0x18,
		0x32, 0x14, 0xbe, 0xf0, 0xbc, 0x08, 0xa3, 0xe4, 0xbe, 0x18, 0xf8, 0xad, 0x61, 0x01, 0xbf, 0x55,
		0xf6, 0x66, 0xd0, 0x07, 0xf9, 0x8f, 0x52, 0xd8, 0x15, 0x0c, 0x38, 0xb2, 0x66, 0x8b, 0x28, 0x97,
		0xc1, 0xdd, 0xe7, 0x53, 0xa3, 0x8d, 0xa1, 0xb0, 0x30, 0xe5, 0x3f, 0x48, 0x70, 0x2a, 0xbd, 0x09,
		0xa6, 0xdf, 0x00, 0xfc, 0xc3, 0x58, 0xd1, 0xcf, 0x73, 0x70, 0x5a, 0xa0, 0x95, 0xcc, 0x5b, 0x93,
		0x8e, 0x5d, 0xd5, 0xa8, 0x3b, 0x42, 0x9b, 0x14, 0x10, 0x3f, 0xb6, 0x35, 0x45, 0x23, 0xa4, 0xa1,
		0x7e, 0x22, 0xa4, 0x3d, 0xab, 0xf8, 0x57, 0x24, 0x98, 0x13, 0xef, 0x00, 0x13, 0x39, 0xf3, 0x06,
		0x73, 0x05, 0x7b, 0x47, 0x82, 0x8c, 0xbd, 0x5e, 0xe9, 0xd8, 0x0e, 0x06, 0x61, 0x90, 0xef, 0x61,
		0x68, 0x60, 0x23, 0x82, 0x38, 0x2f, 0x80, 0xf8, 0xcd, 0x88, 0x1e, 0xf2, 0xaa, 0x42, 0xfd, 0xea,
		0xe1, 0x2a, 0xcc, 0xd4, 0x55, 0xb7, 0xa7, 0xe7, 0x21, 0xda, 0x01, 0xd0, 0x95, 0xac, 0x4f, 0xc7,
		0xda, 0x4a, 0x3f, 0x6c, 0x62, 0xe8, 0x73, 0x3e, 0x83, 0x3e, 0x0f, 0xa5, 0xda, 0x68, 0x24, 0xd0,
		0x93, 0xdf, 0x95, 0xe0, 0x68, 0x42, 0x97, 0x25, 0x9a, 0x86, 0x11, 0xbf, 0xbb, 0xac, 0xb3, 0x6f,
		0x45, 0xf2, 0x5c, 0xd5, 0xd1, 0x1a, 0x1c, 0xea, 0x1c, 0xe4, 0x9b, 0x86, 0x9d, 0xe1, 0xd2, 0x8a,
		0xe8, 0x39, 0xbe, 0x6a, 0xd8, 0x38, 0xcb, 0xf1, 0x2b, 0xb2, 0xd9, 0x9f, 0x81, 0x69, 0x6e, 0xfb,
		0x66, 0xd2, 0x6a, 0x84, 0x63, 0x76, 0xf9, 0x37, 0x12, 0x1c, 0x4b, 0xea, 0xdc, 0x1b, 0xc8, 0x57,
		0x06, 0x25, 0x8f, 0x44, 0x07, 0xfd, 0x13, 0x09, 0x66, 0xd2, 0x3a, 0x00, 0x93, 0x56, 0xf3, 0x58,
		0xcd, 0x36, 0x11, 0xf9, 0xbf, 0x8b, 0x90, 0xb1, 0xd1, 0x04, 0x2d, 0xc0, 0x41, 0xd2, 0xcb, 0x12,
		0x4d, 0xfb, 0xfa, 0x6b, 0x9a, 0x30, 0x71, 0x3b, 0x92, 0xf4, 0x8d, 0x55, 0x5e, 0x72, 0xfd, 0x55,
		0x5e, 0x9e, 0xd4, 0x46, 0xc4, 0x6b, 0x23, 0x22, 0xba, 0x53, 0x14, 0xd0, 0x9d, 0x3b, 0x30, 0x49,
		0x73, 0xda, 0x14, 0xa3, 0x61, 0xba, 0xd8, 0xde, 0x51, 0xeb, 0xe9, 0xf7, 0x96, 0x83, 0x74, 0x22,
		0x81, 0x57, 0xa5, 0xd3, 0xc2, 0x75, 0x97, 0xd2, 0x9e, 0xea, 0x2e, 0x3d, 0x21, 0x1c, 0x64, 0x09,
		0xe1, 0xf8, 0x45, 0x96, 0x72, 0xdf, 0x45, 0x96, 0xee, 0x3d, 0x63, 0x54, 0xf8, 0x9e, 0xd1, 0x49,
		0xf5, 0xef, 0xdb, 0x43, 0xaa, 0x7f, 0x6c, 0x4f, 0xa9, 0x7e, 0xcf, 0x07, 0x2f, 0x64, 0xed, 0x76,
		0xeb, 0x78, 0x2b, 0xa9, 0xd7, 0x5b, 0x25, 0xdd, 0x6f, 0x36, 0xe0, 0x70, 0xa7, 0x42, 0x1e, 0xa9,
		0x9a, 0xfa, 0x76, 0x3c, 0x97, 0x58, 0x03, 0x0f, 0xd7, 0x4d, 0x0f, 0x61, 0xd6, 0xb0, 0xfc, 0x3d,
		0x89, 0x91, 0xd2, 0xe6, 0x9d, 0x2c, 0x22, 0xe6, 0x21, 0x09, 0x98, 0x47, 0x4f, 0xa4, 0x93, 0xcb,
		0x10, 0xe9, 0xc8, 0xef, 0x4b, 0x70, 0x3c, 0xb1, 0x5b, 0xdb, 0x0b, 0xf5, 0x68, 0x2f, 0xb8, 0xa9,
		0x36, 0x02, 0x51, 0x83, 0x3f, 0x74, 0x5b, 0x6d, 0xe0, 0x7e, 0x3f, 0x3d, 0xb0, 0x53, 0xa5, 0xab,
		0xf1, 0x43, 0xe2, 0x37, 0xeb, 0xaf, 0xb1, 0x36, 0x89, 0xd7, 0x9d, 0x70, 0x12, 0xca, 0xb4, 0x3f,
		0xa4, 0x57, 0x04, 0xfe, 0x10, 0x11, 0x41, 0xc7, 0xa9, 0xe7, 0xc4, 0x9d, 0x7a, 0x42, 0x9e, 0x5a,
		0xfe, 0xaa, 0x04, 0x73, 0x19, 0x3a, 0x72, 0xba, 0xf9, 0x54, 0x29, 0x94, 0x4f, 0xed, 0x77, 0x67,
		0x92, 0xa0, 0xfd, 0x32, 0x07, 0x2f, 0xec, 0xad, 0x2b, 0x79, 0x60, 0x3a, 0xdf, 0xcd, 0xd5, 0xe5,
		0x42, 0xb9, 0xba, 0xfb, 0x80, 0xe2, 0xdd, 0x2f, 0xd4, 0xbe, 0xcf, 0x8a, 0x75, 0xb8, 0x2a, 0x13,
		0xb1, 0x16, 0x56, 0x34, 0x05, 0x45, 0xcd, 0x32, 0x5d, 0xdb, 0xaa, 0x13, 0x45, 0x1b, 0x55, 0x82,
		0x47, 0x54, 0x81, 0x03, 0x91, 0x46, 0x2e, 0xcb, 0xac, 0xfb, 0x91, 0xf9, 0x88, 0x32, 0x11, 0xea,
		0xaf, 0xba, 0x63, 0xd6, 0x77, 0xe5, 0x37, 0xf2, 0x70, 0x63, 0x0f, 0x5d, 0xcf, 0xe8, 0x7e, 0xaf,
		0xdf, 0x1b, 0xe3, 0xfc, 0xa6, 0x40, 0x88, 0x73, 0x28, 0xed, 0x3c, 0xa0, 0xfb, 0x24, 0x37, 0x87,
		0xca, 0xde, 0x97, 0xa1, 0xbd, 0xee, 0xcb, 0x3c, 0xa0, 0x68, 0xaf, 0x19, 0xad, 0x50, 0xe4, 0x95,
		0x71, 0x23, 0xa4, 0x84, 0x7e, 0x0a, 0x2b, 0xd8, 0xc5, 0x42, 0x68, 0x17, 0xe5, 0x3f, 0x49, 0x70,
		0xad, 0xcf, 0x96, 0x6d, 0x0e, 0x06, 0x89, 0x83, 0xe1, 0x83, 0x55, 0x5c, 0xf9, 0x4b, 0x79, 0xb8,
		0xd6, 0x67, 0x5b, 0xdd, 0xff, 0xaa, 0xad, 0x46, 0x3c, 0xf6, 0x10, 0xdf, 0x63, 0x0f, 0x8b, 0x7b,
		0x6c, 0xae, 0xea, 0xf0, 0x1c, 0x40, 0x91, 0xe7, 0x00, 0x5e, 0xcd, 0xc3, 0x95, 0x7e, 0x5a, 0x03,
		0xc5, 0x2c, 0x5f, 0x88, 0xf3, 0x13, 0xcb, 0xef, 0x5a, 0xfe, 0x7b, 0x12, 0x5c, 0xcc, 0xda, 0xe6,
		0xf8, 0x5f, 0x6d, 0xf2, 0xfc, 0xb3, 0x4a, 0xfe, 0x9d, 0x04, 0x17, 0x32, 0xb5, 0x46, 0x0e, 0xcc,
		0x05, 0x30, 0x6f, 0x0d, 0xb9, 0xbd, 0xdd, 0x1a, 0xfe, 0x32, 0x02, 0x97, 0xfb, 0xf8, 0x8d, 0x47,
		0xcf, 0x76, 0x48, 0xa1, 0xed, 0x38, 0x09, 0xe5, 0xce, 0x76, 0x50, 0x9d, 0x2f, 0x29, 0x10, 0x0c,
		0xb1, 0x52, 0x08, 0xf9, 0x01, 0xa4, 0x10, 0xfa, 0xad, 0x27, 0x0e, 0x0f, 0x36, 0x85, 0x50, 0x78,
		0xac, 0x29, 0x84, 0x62, 0xdf, 0x29, 0x84, 0x07, 0x40, 0x3b, 0x54, 0x29, 0x47, 0x5a, 0x86, 0xf3,
		0x9b, 0x04, 0xce, 0x26, 0xb4, 0xb9, 0x12, 0x2e, 0xb4, 0x18, 0x37, 0xd1, 0x8c, 0x0e, 0xf5, 0x1a,
		0x49, 0x29, 0xec, 0xcf, 0x45, 0x54, 0x1e, 0x04, 0x54, 0x5e, 0x83, 0xa9, 0x1e, 0x75, 0xaa, 0xd9,
		0xb8, 0xd5, 0x85, 0x5f, 0x26, 0xf0, 0xe7, 0x12, 0x15, 0xa7, 0xaa, 0x2b, 0xde, 0x14, 0xba, 0x84,
		0x43, 0x6d, 0xd6, 0x70, 0xac, 0x3c, 0xb9, 0xaf, 0x9f, 0xf2, 0x64, 0xac, 0xd7, 0x70, 0x8c, 0xd1,
		0x6b, 0xd8, 0xbd, 0x69, 0xed, 0xcf, 0x9e, 0x5b, 0x18, 0xdf, 0x43, 0x6e, 0x61, 0x62, 0x6f, 0x6d,
		0x84, 0xcf, 0x41, 0x59, 0xc7, 0x75, 0x75, 0xd7, 0x57, 0xcd, 0xf4, 0x9e, 0x48, 0x20, 0xd4, 0x44,
		0x15, 0xe5, 0xd7, 0xf3, 0x70, 0x31, 0xeb, 0x6f, 0xb0, 0x3e, 0x7c, 0xf7, 0xb2, 0x16, 0xc4, 0x09,
		0x7e, 0xa5, 0xeb, 0x6a, 0xe6, 0x1f, 0x10, 0x85, 0xc2, 0x83, 0x1e, 0x43, 0x19, 0x0e, 0x1b, 0x0a,
		0xfb, 0x10, 0x2c, 0x70, 0x0e, 0xc1, 0x01, 0xe5, 0x02, 0xe5, 0xdf, 0xe6, 0x60, 0x3e, 0xcb, 0x0f,
		0xcc, 0xb8, 0xfb, 0xc1, 0x3e, 0x7d, 0x73, 0x7b, 0x3d, 0x7d, 0x07, 0xb5, 0x8b, 0x6c, 0xe9, 0x0e,
		0x71, 0xa4, 0xdb, 0xb5, 0xce, 0x61, 0xf1, 0x3c, 0xc8, 0xfb, 0x39, 0xc8, 0xf8, 0xd3, 0xb7, 0x8f,
		0x86, 0x30, 0x59, 0x65, 0x9d, 0x61, 0x66, 0x59, 0xa7, 0xdb, 0x8f, 0x50, 0x10, 0xef, 0x47, 0x90,
		0xff, 0x99, 0x83, 0xf3, 0x83, 0xf0, 0x28, 0x1f, 0x51, 0xa1, 0xf7, 0x64, 0xdc, 0x0b, 0x19, 0x32,
		0xee, 0xf2, 0xbf, 0x72, 0x70, 0x21, 0xd3, 0x2f, 0x11, 0x9f, 0x08, 0x3e, 0x26, 0xf8, 0x20, 0xa5,
		0x58, 0xc8, 0x92, 0x67, 0xfe, 0x7c, 0x9e, 0x27, 0x78, 0x5e, 0x0f, 0xc9, 0x13, 0xc1, 0x27, 0xb6,
		0xb0, 0x14, 0xfa, 0xe9, 0x7d, 0xff, 0x45, 0x0e, 0x16, 0x32, 0xfe, 0x42, 0xf4, 0xc9, 0x3e, 0x84,
		0xf6, 0x61, 0xce, 0x85, 0xfd, 0xe4, 0xcf, 0x55, 0xa3, 0xee, 0x62, 0x9b, 0x7c, 0xea, 0x38, 0x4c,
		0xaf, 0x3c, 0x58, 0xb9, 0xbd, 0x5e, 0x5b, 0xad, 0xae, 0xad, 0xaf, 0x28, 0xb5, 0xf5, 0x4f, 0xde,
		0x5d, 0xa9, 0x55, 0x6f, 0x3f, 0x58, 0x5a, 0xab, 0xde, 0x1a, 0x7f, 0x0a, 0x9d, 0x84, 0xa3, 0xf1,
		0xd7, 0x4b, 0x6b, 0x6b, 0x35, 0x32, 0x3a, 0x2e, 0xa1, 0x53, 0x70, 0x3c, 0x4e, 0xb0, 0xbc, 0x76,
		0xe7, 0xde, 0x0a, 0x25, 0xc9, 0xdd, 0x7c, 0x00, 0x87, 0x35, 0xab, 0xc1, 0x92, 0xc1, 0xcd, 0x91,
		0xa5, 0xa6, 0x71, 0xd7, 0x0b, 0x61, 0xef, 0x4a, 0x9f, 0x5a, 0x78, 0x68, 0xb8, 0x5b, 0xad, 0x8d,
		0x8a, 0x66, 0x35, 0x16, 0x42, 0xff, 0xe7, 0xb4, 0xf2, 0x10, 0x9b, 0xfe, 0x7f, 0x56, 0xa5, 0xff,
		0xf2, 0xf4, 0x86, 0xda, 0x34, 0x76, 0x2e, 0x6d, 0x14, 0xc8, 0xd8, 0xe5, 0xff, 0x04, 0x00, 0x00,
		0xff, 0xff, 0xee, 0x07, 0x38, 0xbd, 0xd5, 0x55, 0x00, 0x00,
	},
	// google/protobuf/timestamp.proto
	[]byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xe2, 0x92, 0x4f, 0xcf, 0xcf, 0x4f,
		0xcf, 0x49, 0xd5, 0x2f, 0x28, 0xca, 0x2f, 0xc9, 0x4f, 0x2a, 0x4d, 0xd3, 0x2f, 0xc9, 0xcc, 0x4d,
		0x2d, 0x2e, 0x49, 0xcc, 0x2d, 0xd0, 0x03, 0x0b, 0x09, 0xf1, 0x43, 0x14, 0xe8, 0xc1, 0x14, 0x28,
		0x59, 0x73, 0x71, 0x86, 0xc0, 0xd4, 0x08, 0x49, 0x70, 0xb1, 0x17, 0xa7, 0x26, 0xe7, 0xe7, 0xa5,
		0x14, 0x4b, 0x30, 0x2a, 0x30, 0x6a, 0x30, 0x07, 0xc1, 0xb8, 0x42, 0x22, 0x5c, 0xac, 0x79, 0x89,
		0x79, 0xf9, 0xc5, 0x12, 0x4c, 0x0a, 0x8c, 0x1a, 0xac, 0x41, 0x10, 0x8e, 0x53, 0x2b, 0x23, 0x97,
		0x70, 0x72, 0x7e, 0xae, 0x1e, 0x9a, 0xa1, 0x4e, 0x7c, 0x70, 0x23, 0x03, 0x40, 0x42, 0x01, 0x8c,
		0x51, 0x46, 0x50, 0x25, 0xe9, 0xf9, 0x39, 0x89, 0x79, 0xe9, 0x7a, 0xf9, 0x45, 0xe9, 0x48, 0x6e,
		0xac, 0x2c, 0x48, 0x2d, 0xd6, 0xcf, 0xce, 0xcb, 0x2f, 0xcf, 0x43, 0xb8, 0xb7, 0x20, 0xe9, 0x07,
		0x23, 0xe3, 0x22, 0x26, 0x66, 0xf7, 0x00, 0xa7, 0x55, 0x4c, 0x72, 0xee, 0x10, 0xdd, 0x01, 0x50,
		0x2d, 0x7a, 0xe1, 0xa9, 0x39, 0x39, 0xde, 0x20, 0x0d, 0x21, 0x20, 0xbd, 0x49, 0x6c, 0x60, 0xb3,
		0x8c, 0x01, 0x01, 0x00, 0x00, 0xff, 0xff, 0xae, 0x65, 0xce, 0x7d, 0xff, 0x00, 0x00, 0x00,
	},
	// uber/cadence/api/v1/tasklist.proto
	[]byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x7c, 0x54, 0xdd, 0x6e, 0xdb, 0x36,
		0x14, 0x9e, 0xe2, 0xb4, 0x73, 0x98, 0x25, 0xd5, 0xb8, 0xb5, 0x8d, 0xdd, 0x75, 0xcb, 0x74, 0x51,
		0x04, 0xc5, 0x20, 0x21, 0x19, 0x76, 0xb5, 0x8b, 0xc1, 0x89, 0x83, 0x55, 0x88, 0xe3, 0x1a, 0x92,
		0x1a, 0x20, 0xbb, 0xe1, 0x28, 0xf1, 0xd4, 0x21, 0xf4, 0x43, 0x81, 0xa4, 0x92, 0xf8, 0x45, 0xf6,
		0x30, 0x7b, 0xa2, 0x3d, 0xc6, 0x40, 0x4a, 0xf6, 0xdc, 0xc4, 0xeb, 0x1d, 0x79, 0xbe, 0xf3, 0x9d,
		0x9f, 0x8f, 0xe7, 0x10, 0x79, 0x4d, 0x0a, 0x32, 0xc8, 0x28, 0x83, 0x2a, 0x83, 0x80, 0xd6, 0x3c,
		0xb8, 0x3d, 0x0e, 0x34, 0x55, 0x79, 0xc1, 0x95, 0xf6, 0x6b, 0x29, 0xb4, 0xc0, 0xdf, 0x18, 0x1f,
		0xbf, 0xf3, 0xf1, 0x69, 0xcd, 0xfd, 0xdb, 0xe3, 0xe1, 0xf7, 0x73, 0x21, 0xe6, 0x05, 0x04, 0xd6,
		0x25, 0x6d, 0x3e, 0x06, 0xac, 0x91, 0x54, 0x73, 0x51, 0xb5, 0xa4, 0xe1, 0x0f, 0x0f, 0x71, 0xcd,
		0x4b, 0x50, 0x9a, 0x96, 0x75, 0xe7, 0xf0, 0x28, 0xc0, 0x9d, 0xa4, 0x75, 0x0d, 0x52, 0xb5, 0xb8,
		0xf7, 0x01, 0xf5, 0x13, 0xaa, 0xf2, 0x09, 0x57, 0x1a, 0x63, 0xb4, 0x5d, 0xd1, 0x12, 0x0e, 0x9c,
		0x43, 0xe7, 0x68, 0x27, 0xb2, 0x67, 0xfc, 0x0b, 0xda, 0xce, 0x79, 0xc5, 0x0e, 0xb6, 0x0e, 0x9d,
		0xa3, 0xfd, 0x93, 0x1f, 0xfd, 0x0d, 0x45, 0xfa, 0xcb, 0x00, 0x17, 0xbc, 0x62, 0x91, 0x75, 0xf7,
		0x28, 0x72, 0x97, 0xd6, 0x4b, 0xd0, 0x94, 0x51, 0x4d, 0xf1, 0x25, 0xfa, 0xb6, 0xa4, 0xf7, 0xc4,
		0xb4, 0xad, 0x48, 0x0d, 0x92, 0x28, 0xc8, 0x44, 0xc5, 0x6c, 0xba, 0xdd, 0x93, 0xef, 0xfc, 0xb6,
		0x52, 0x7f, 0x59, 0xa9, 0x3f, 0x16, 0x4d, 0x5a, 0xc0, 0x15, 0x2d, 0x1a, 0x88, 0xbe, 0x2e, 0xe9,
		0xbd, 0x09, 0xa8, 0x66, 0x20, 0x63, 0x4b, 0xf3, 0x3e, 0xa0, 0xc1, 0x32, 0xc5, 0x8c, 0x4a, 0xcd,
		0x8d, 0x2a, 0xab, 0x5c, 0x2e, 0xea, 0xe5, 0xb0, 0xe8, 0x3a, 0x31, 0x47, 0xfc, 0x06, 0x3d, 0x13,
		0x77, 0x15, 0x48, 0x72, 0x23, 0x94, 0x26, 0xb6, 0xcf, 0x2d, 0x8b, 0xee, 0x59, 0xf3, 0x3b, 0xa1,
		0xf4, 0x94, 0x96, 0xe0, 0xfd, 0xe3, 0xa0, 0xfd, 0x65, 0xdc, 0x58, 0x53, 0xdd, 0x28, 0xfc, 0x13,
		0xc2, 0x29, 0xcd, 0xf2, 0x42, 0xcc, 0x49, 0x26, 0x9a, 0x4a, 0x93, 0x1b, 0x5e, 0x69, 0x1b, 0xbb,
		0x17, 0xb9, 0x1d, 0x72, 0x66, 0x80, 0x77, 0xbc, 0xd2, 0xf8, 0x35, 0x42, 0x12, 0x28, 0x23, 0x05,
		0xdc, 0x42, 0x61, 0x73, 0xf4, 0xa2, 0x1d, 0x63, 0x99, 0x18, 0x03, 0x7e, 0x85, 0x76, 0x68, 0x96,
		0x77, 0x68, 0xcf, 0xa2, 0x7d, 0x9a, 0xe5, 0x2d, 0xf8, 0x06, 0x3d, 0x93, 0x54, 0xc3, 0xba, 0x3a,
		0xdb, 0x87, 0xce, 0x91, 0x13, 0xed, 0x19, 0xf3, 0xaa, 0x77, 0x3c, 0x46, 0x7b, 0x46, 0x46, 0xc2,
		0x19, 0x49, 0x0b, 0x91, 0xe5, 0x07, 0x4f, 0xac, 0x86, 0x87, 0xff, 0xfb, 0x3c, 0xe1, 0xf8, 0xd4,
		0xf8, 0x45, 0xbb, 0x86, 0x16, 0x32, 0x7b, 0xf1, 0x7e, 0x43, 0xbb, 0x6b, 0x18, 0x1e, 0xa0, 0xbe,
		0xd2, 0x54, 0x6a, 0xc2, 0x59, 0xd7, 0xdc, 0x97, 0xf6, 0x1e, 0x32, 0xfc, 0x1c, 0x3d, 0x85, 0x8a,
		0x19, 0xa0, 0xed, 0xe7, 0x09, 0x54, 0x2c, 0x64, 0xde, 0x5f, 0x0e, 0x42, 0x33, 0x51, 0x14, 0x20,
		0xc3, 0xea, 0xa3, 0xc0, 0x63, 0xe4, 0x16, 0x54, 0x69, 0x42, 0xb3, 0x0c, 0x94, 0x22, 0x66, 0x14,
		0xbb, 0xc7, 0x1d, 0x3e, 0x7a, 0xdc, 0x64, 0x39, 0xa7, 0xd1, 0xbe, 0xe1, 0x8c, 0x2c, 0xc5, 0x18,
		0xf1, 0x10, 0xf5, 0x39, 0x83, 0x4a, 0x73, 0xbd, 0xe8, 0x5e, 0x68, 0x75, 0xdf, 0xa4, 0x4f, 0x6f,
		0x83, 0x3e, 0xde, 0xdf, 0x0e, 0x1a, 0xc4, 0x9a, 0x67, 0xf9, 0xe2, 0xfc, 0x1e, 0xb2, 0xc6, 0x8c,
		0xc6, 0x48, 0x6b, 0xc9, 0xd3, 0x46, 0x83, 0xc2, 0xbf, 0x23, 0xf7, 0x4e, 0xc8, 0x1c, 0xa4, 0x9d,
		0x45, 0x62, 0x76, 0xb0, 0xab, 0xf3, 0xf5, 0x67, 0xe7, 0x3b, 0xda, 0x6f, 0x69, 0xab, 0x85, 0x49,
		0xd0, 0x40, 0x65, 0x37, 0xc0, 0x9a, 0x02, 0x88, 0x16, 0xa4, 0x55, 0xcf, 0xb4, 0x2d, 0x1a, 0x6d,
		0x6b, 0xdf, 0x3d, 0x19, 0x3c, 0x1e, 0xeb, 0x6e, 0x83, 0xa3, 0x17, 0x4b, 0x6e, 0x22, 0x62, 0xc3,
		0x4c, 0x5a, 0xe2, 0xdb, 0x3f, 0xd1, 0x57, 0xeb, 0x1b, 0x85, 0x87, 0xe8, 0x45, 0x32, 0x8a, 0x2f,
		0xc8, 0x24, 0x8c, 0x13, 0x72, 0x11, 0x4e, 0xc7, 0x24, 0x9c, 0x5e, 0x8d, 0x26, 0xe1, 0xd8, 0xfd,
		0x02, 0x0f, 0xd0, 0xf3, 0x07, 0xd8, 0xf4, 0x7d, 0x74, 0x39, 0x9a, 0xb8, 0xce, 0x06, 0x28, 0x4e,
		0xc2, 0xb3, 0x8b, 0x6b, 0x77, 0xeb, 0x2d, 0xfb, 0x2f, 0x43, 0xb2, 0xa8, 0xe1, 0xd3, 0x0c, 0xc9,
		0xf5, 0xec, 0x7c, 0x2d, 0xc3, 0x2b, 0xf4, 0xf2, 0x01, 0x36, 0x3e, 0x3f, 0x0b, 0xe3, 0xf0, 0xfd,
		0xd4, 0x75, 0x36, 0x80, 0xa3, 0xb3, 0x24, 0xbc, 0x0a, 0x93, 0x6b, 0x77, 0xeb, 0xf4, 0x0a, 0xbd,
		0xcc, 0x44, 0xb9, 0x49, 0xd1, 0xd3, 0xfe, 0xa8, 0xe6, 0x33, 0x23, 0xc8, 0xcc, 0xf9, 0x23, 0x98,
		0x73, 0x7d, 0xd3, 0xa4, 0x7e, 0x26, 0xca, 0xe0, 0x93, 0x6f, 0xd2, 0x9f, 0x43, 0xd5, 0xfe, 0x5b,
		0xdd, 0x8f, 0xf9, 0x2b, 0xad, 0xf9, 0xed, 0x71, 0xfa, 0xd4, 0xda, 0x7e, 0xfe, 0x37, 0x00, 0x00,
		0xff, 0xff, 0x58, 0x62, 0x2b, 0xbf, 0x55, 0x05, 0x00, 0x00,
	},
	// google/protobuf/wrappers.proto
	[]byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xe2, 0x92, 0x4b, 0xcf, 0xcf, 0x4f,
		0xcf, 0x49, 0xd5, 0x2f, 0x28, 0xca, 0x2f, 0xc9, 0x4f, 0x2a, 0x4d, 0xd3, 0x2f, 0x2f, 0x4a, 0x2c,
		0x28, 0x48, 0x2d, 0x2a, 0xd6, 0x03, 0x8b, 0x08, 0xf1, 0x43, 0xe4, 0xf5, 0x60, 0xf2, 0x4a, 0xca,
		0x5c, 0xdc, 0x2e, 0xf9, 0xa5, 0x49, 0x39, 0xa9, 0x61, 0x89, 0x39, 0xa5, 0xa9, 0x42, 0x22, 0x5c,
		0xac, 0x65, 0x20, 0x86, 0x04, 0xa3, 0x02, 0xa3, 0x06, 0x63, 0x10, 0x84, 0xa3, 0xa4, 0xc4, 0xc5,
		0xe5, 0x96, 0x93, 0x9f, 0x58, 0x82, 0x45, 0x0d, 0x13, 0x92, 0x1a, 0xcf, 0xbc, 0x12, 0x33, 0x13,
		0x2c, 0x6a, 0x98, 0x61, 0x6a, 0x94, 0xb9, 0xb8, 0x43, 0x71, 0x29, 0x62, 0x41, 0x35, 0xc8, 0xd8,
		0x08, 0x8b, 0x1a, 0x56, 0x34, 0x83, 0xb0, 0x2a, 0xe2, 0x85, 0x29, 0x52, 0xe4, 0xe2, 0x74, 0xca,
		0xcf, 0xcf, 0xc1, 0xa2, 0x84, 0x03, 0xc9, 0x9c, 0xe0, 0x92, 0xa2, 0xcc, 0xbc, 0x74, 0x2c, 0x8a,
		0x38, 0x91, 0x1c, 0xe4, 0x54, 0x59, 0x92, 0x5a, 0x8c, 0x45, 0x0d, 0x0f, 0x54, 0x8d, 0x53, 0x33,
		0x23, 0x97, 0x70, 0x72, 0x7e, 0xae, 0x1e, 0x5a, 0xf0, 0x3a, 0xf1, 0x86, 0x43, 0xc3, 0x3f, 0x00,
		0x24, 0x12, 0xc0, 0x18, 0x65, 0x08, 0x55, 0x91, 0x9e, 0x9f, 0x93, 0x98, 0x97, 0xae, 0x97, 0x5f,
		0x94, 0x8e, 0x88, 0xab, 0x92, 0xca, 0x82, 0xd4, 0x62, 0xfd, 0xec, 0xbc, 0xfc, 0xf2, 0x3c, 0x78,
		0xbc, 0x15, 0x24, 0xfd, 0x60, 0x64, 0x5c, 0xc4, 0xc4, 0xec, 0x1e, 0xe0, 0xb4, 0x8a, 0x49, 0xce,
		0x1d, 0xa2, 0x39, 0x00, 0xaa, 0x43, 0x2f, 0x3c, 0x35, 0x27, 0xc7, 0x1b, 0xa4, 0x3e, 0x04, 0xa4,
		0x35, 0x89, 0x0d, 0x6c, 0x94, 0x31, 0x20, 0x00, 0x00, 0xff, 0xff, 0x3c, 0x92, 0x48, 0x30, 0x06,
		0x02, 0x00, 0x00,
	},
	// uber/cadence/api/v1/workflow.proto
	[]byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xc4, 0x59, 0x4d, 0x6f, 0xdb, 0xca,
		0xd5, 0x7e, 0x29, 0xd9, 0x8e, 0x7d, 0xe4, 0x0f, 0x7a, 0x1c, 0xc7, 0xca, 0xb7, 0xa3, 0xfb, 0x26,
		0x71, 0xd4, 0x1b, 0xf9, 0x3a, 0xb9, 0xb9, 0x69, 0x6e, 0x9a, 0xa6, 0x34, 0x49, 0xc7, 0x4c, 0x64,
		0x4a, 0x1d, 0x51, 0x71, 0x7c, 0x51, 0x94, 0xa0, 0xa5, 0xb1, 0x4d, 0x44, 0x22, 0x05, 0x72, 0x94,
		0xc4, 0xfb, 0x02, 0x5d, 0x77, 0x57, 0xb4, 0x9b, 0xfe, 0x80, 0x02, 0x45, 0x7f, 0x40, 0xd1, 0xa2,
		0x8b, 0xee, 0xba, 0xed, 0xb2, 0xfb, 0xfe, 0x8b, 0x62, 0x86, 0x43, 0x89, 0xb2, 0x3e, 0xa8, 0xb4,
		0xc0, 0xed, 0xce, 0x3c, 0x7c, 0x9e, 0x87, 0x67, 0xce, 0x9c, 0xf3, 0x70, 0x68, 0x41, 0xa1, 0x7b,
		0x4c, 0x82, 0xed, 0x86, 0xd3, 0x24, 0x5e, 0x83, 0x6c, 0x3b, 0x1d, 0x77, 0xfb, 0xc3, 0xce, 0xf6,
		0x47, 0x3f, 0x78, 0x7f, 0xd2, 0xf2, 0x3f, 0x96, 0x3a, 0x81, 0x4f, 0x7d, 0xb4, 0xc6, 0x30, 0x25,
		0x81, 0x29, 0x39, 0x1d, 0xb7, 0xf4, 0x61, 0xe7, 0xda, 0xad, 0x53, 0xdf, 0x3f, 0x6d, 0x91, 0x6d,
		0x0e, 0x39, 0xee, 0x9e, 0x6c, 0x37, 0xbb, 0x81, 0x43, 0x5d, 0xdf, 0x8b, 0x48, 0xd7, 0x6e, 0x5f,
		0xbc, 0x4f, 0xdd, 0x36, 0x09, 0xa9, 0xd3, 0xee, 0x08, 0xc0, 0xe6, 0xa8, 0x27, 0x37, 0xfc, 0x76,
		0xbb, 0x27, 0x31, 0x32, 0x37, 0xea, 0x84, 0xef, 0x5b, 0x6e, 0x48, 0x23, 0x4c, 0xe1, 0x2f, 0x73,
		0xb0, 0x7e, 0x28, 0xd2, 0xd5, 0x3f, 0x91, 0x46, 0x97, 0xa5, 0x60, 0x78, 0x27, 0x3e, 0xaa, 0x03,
		0x8a, 0xd7, 0x61, 0x93, 0xf8, 0x4e, 0x5e, 0xda, 0x94, 0xb6, 0x72, 0x8f, 0xee, 0x95, 0x46, 0x2c,
		0xa9, 0x34, 0xa4, 0x83, 0x57, 0x3f, 0x5e, 0x0c, 0xa1, 0x27, 0x30, 0x43, 0xcf, 0x3b, 0x24, 0x9f,
		0xe1, 0x42, 0x77, 0x26, 0x0a, 0x59, 0xe7, 0x1d, 0x82, 0x39, 0x1c, 0x3d, 0x03, 0x08, 0xa9, 0x13,
		0x50, 0x9b, 0x95, 0x21, 0x9f, 0xe5, 0xe4, 0x6b, 0xa5, 0xa8, 0x46, 0xa5, 0xb8, 0x46, 0x25, 0x2b,
		0xae, 0x11, 0x5e, 0xe0, 0x68, 0x76, 0xcd, 0xa8, 0x8d, 0x96, 0x1f, 0x92, 0x88, 0x3a, 0x93, 0x4e,
		0xe5, 0x68, 0x4e, 0xb5, 0x60, 0x31, 0xa2, 0x86, 0xd4, 0xa1, 0xdd, 0x30, 0x3f, 0xbb, 0x29, 0x6d,
		0x2d, 0x3f, 0xda, 0x99, 0x6e, 0xf5, 0x2a, 0x63, 0xd6, 0x38, 0x11, 0xe7, 0x1a, 0xfd, 0x0b, 0x74,
		0x17, 0x96, 0xcf, 0xdc, 0x90, 0xfa, 0xc1, 0xb9, 0xdd, 0x22, 0xde, 0x29, 0x3d, 0xcb, 0xcf, 0x6d,
		0x4a, 0x5b, 0x59, 0xbc, 0x24, 0xa2, 0x65, 0x1e, 0x44, 0x3f, 0x83, 0xf5, 0x8e, 0x13, 0x10, 0x8f,
		0xf6, 0xcb, 0x6f, 0xbb, 0xde, 0x89, 0x9f, 0xbf, 0xc4, 0x97, 0xb0, 0x35, 0x32, 0x8b, 0x2a, 0x67,
		0x0c, 0xec, 0x24, 0x5e, 0xeb, 0x0c, 0x07, 0x91, 0x02, 0xcb, 0x7d, 0x59, 0x5e, 0x99, 0xf9, 0xd4,
		0xca, 0x2c, 0xf5, 0x18, 0xbc, 0x3a, 0x0f, 0x61, 0xa6, 0x4d, 0xda, 0x7e, 0x7e, 0x81, 0x13, 0xaf,
		0x8e, 0xcc, 0xe7, 0x80, 0xb4, 0x7d, 0xcc, 0x61, 0x08, 0xc3, 0x6a, 0x48, 0x9c, 0xa0, 0x71, 0x66,
		0x3b, 0x94, 0x06, 0xee, 0x71, 0x97, 0x92, 0x30, 0x0f, 0x9c, 0x7b, 0x77, 0x24, 0xb7, 0xc6, 0xd1,
		0x4a, 0x0f, 0x8c, 0xe5, 0xf0, 0x42, 0x04, 0x95, 0x61, 0xd5, 0xe9, 0x52, 0xdf, 0x0e, 0x48, 0x48,
		0xa8, 0xdd, 0xf1, 0x5d, 0x8f, 0x86, 0xf9, 0x1c, 0xd7, 0xdc, 0x1c, 0xa9, 0x89, 0x19, 0xb0, 0xca,
		0x71, 0x78, 0x85, 0x51, 0x13, 0x01, 0x74, 0x1d, 0x16, 0xd8, 0x78, 0xd8, 0x6c, 0x3e, 0xf2, 0x8b,
		0x9b, 0xd2, 0xd6, 0x02, 0x9e, 0x67, 0x81, 0xb2, 0x1b, 0x52, 0xb4, 0x01, 0x97, 0xdc, 0xd0, 0x6e,
		0x04, 0xbe, 0x97, 0x5f, 0xda, 0x94, 0xb6, 0xe6, 0xf1, 0x9c, 0x1b, 0xaa, 0x81, 0xef, 0x15, 0x7e,
		0x9d, 0x81, 0x5b, 0xc3, 0x9b, 0xef, 0x7b, 0x27, 0xee, 0xa9, 0x18, 0x69, 0xf4, 0x6d, 0x52, 0x38,
		0x1a, 0xa1, 0x9b, 0x23, 0xd3, 0xb3, 0xc4, 0xd3, 0x12, 0xcf, 0x75, 0x60, 0xb3, 0xbf, 0x51, 0x62,
		0x06, 0x7c, 0xbb, 0xdf, 0xd1, 0x7e, 0x97, 0x8a, 0x61, 0xba, 0x3a, 0xb4, 0x75, 0x9a, 0x48, 0x00,
		0xdf, 0xe8, 0x49, 0xd4, 0xf8, 0x5c, 0xf8, 0x6a, 0xdc, 0xe3, 0x7e, 0x97, 0xa2, 0x43, 0xb8, 0xce,
		0xd3, 0x1b, 0xa3, 0x9e, 0x4d, 0x53, 0xdf, 0x60, 0xec, 0x11, 0xc2, 0x85, 0xbf, 0x4b, 0xb0, 0x36,
		0xa2, 0x23, 0x59, 0xa1, 0x9b, 0x7e, 0xdb, 0x71, 0x3d, 0xdb, 0x6d, 0xf2, 0x7a, 0x2c, 0xe0, 0xf9,
		0x28, 0x60, 0x34, 0xd1, 0x6d, 0xc8, 0x89, 0x9b, 0x9e, 0xd3, 0x8e, 0x8c, 0x62, 0x01, 0x43, 0x14,
		0x32, 0x9d, 0x36, 0x19, 0xe3, 0x4c, 0xd9, 0xff, 0xd6, 0x99, 0xee, 0xc0, 0xa2, 0xeb, 0xb9, 0xd4,
		0x75, 0x28, 0x69, 0xb2, 0xbc, 0x66, 0xf8, 0x50, 0xe6, 0x7a, 0x31, 0xa3, 0x59, 0xf8, 0x95, 0x04,
		0xeb, 0xfa, 0x27, 0x4a, 0x02, 0xcf, 0x69, 0x7d, 0x2f, 0x6e, 0x79, 0x31, 0xa7, 0xcc, 0x70, 0x4e,
		0xff, 0x9c, 0x85, 0xb5, 0x2a, 0xf1, 0x9a, 0xae, 0x77, 0xaa, 0x34, 0xa8, 0xfb, 0xc1, 0xa5, 0xe7,
		0x3c, 0xa3, 0xdb, 0x90, 0x73, 0xc4, 0x75, 0xbf, 0xca, 0x10, 0x87, 0x8c, 0x26, 0xda, 0x83, 0xa5,
		0x1e, 0x20, 0xd5, 0x92, 0x63, 0x69, 0x6e, 0xc9, 0x8b, 0x4e, 0xe2, 0x0a, 0xbd, 0x84, 0x59, 0x66,
		0x8f, 0x91, 0x2b, 0x2f, 0x3f, 0x7a, 0x30, 0xda, 0x97, 0x06, 0x33, 0x64, 0x4e, 0x48, 0x70, 0xc4,
		0x43, 0x06, 0xac, 0x9e, 0x11, 0x27, 0xa0, 0xc7, 0xc4, 0xa1, 0x76, 0x93, 0x50, 0xc7, 0x6d, 0x85,
		0xc2, 0xa7, 0x6f, 0x8c, 0x31, 0xb9, 0xf3, 0x96, 0xef, 0x34, 0xb1, 0xdc, 0xa3, 0x69, 0x11, 0x0b,
		0xbd, 0x86, 0xb5, 0x96, 0x13, 0x52, 0xbb, 0xaf, 0xc7, 0xad, 0x6d, 0x36, 0xd5, 0xda, 0x56, 0x19,
		0x6d, 0x3f, 0x66, 0x71, 0x7b, 0xdb, 0x03, 0x1e, 0x8c, 0xa6, 0x82, 0x34, 0x23, 0xa5, 0xb9, 0x54,
		0xa5, 0x15, 0x46, 0xaa, 0x45, 0x1c, 0xae, 0x93, 0x87, 0x4b, 0x0e, 0xa5, 0xa4, 0xdd, 0xa1, 0xdc,
		0xb9, 0x67, 0x71, 0x7c, 0x89, 0x1e, 0x80, 0xdc, 0x76, 0x3e, 0xb9, 0xed, 0x6e, 0xdb, 0x16, 0xa1,
		0x90, 0xbb, 0xf0, 0x2c, 0x5e, 0x11, 0x71, 0x45, 0x84, 0x99, 0x5d, 0x87, 0x8d, 0x33, 0xd2, 0xec,
		0xb6, 0xe2, 0x4c, 0x16, 0xd2, 0xed, 0xba, 0xc7, 0xe0, 0x79, 0xa8, 0xb0, 0x42, 0x3e, 0x75, 0xdc,
		0x68, 0x66, 0x23, 0x0d, 0x48, 0xd5, 0x58, 0xee, 0x53, 0xb8, 0xc8, 0x4b, 0x58, 0xe4, 0x45, 0x39,
		0x71, 0xdc, 0x56, 0x37, 0x20, 0xc2, 0x6b, 0x47, 0x6f, 0xd3, 0x5e, 0x84, 0xc1, 0x39, 0xc6, 0x10,
		0x17, 0xe8, 0x2b, 0xb8, 0xcc, 0x05, 0x58, 0xaf, 0x93, 0xc0, 0x76, 0x9b, 0xc4, 0xa3, 0x2e, 0x3d,
		0x17, 0x76, 0x8b, 0xd8, 0xbd, 0x43, 0x7e, 0xcb, 0x10, 0x77, 0x0a, 0xbf, 0xcd, 0xc0, 0x55, 0xd1,
		0x3e, 0xea, 0x99, 0xdb, 0x6a, 0x7e, 0x2f, 0x83, 0xf7, 0x65, 0x42, 0x96, 0x0d, 0x47, 0xd2, 0x8b,
		0xe4, 0x8f, 0x89, 0xf3, 0x09, 0x77, 0xa4, 0x8b, 0x63, 0x9a, 0x1d, 0x1a, 0x53, 0xf4, 0x16, 0xc4,
		0x6b, 0x58, 0x98, 0x6b, 0xc7, 0x6f, 0xb9, 0x8d, 0x73, 0xde, 0xe6, 0xcb, 0x63, 0x12, 0x8d, 0x9c,
		0x93, 0x1b, 0x6a, 0x95, 0xa3, 0xf1, 0x6a, 0xe7, 0x62, 0xa8, 0xf0, 0xb7, 0x4c, 0x6f, 0xfc, 0x35,
		0xd2, 0x70, 0xc3, 0xb8, 0x2e, 0xbd, 0xa9, 0x94, 0xd2, 0xa7, 0x32, 0x26, 0x0e, 0x4c, 0xe5, 0x70,
		0xc7, 0x65, 0x3e, 0xb7, 0xe3, 0x5e, 0xc0, 0xe2, 0xc0, 0xf0, 0xa4, 0x1f, 0xdb, 0x72, 0xe1, 0xe8,
		0xc1, 0x99, 0x19, 0x1c, 0x1c, 0x0c, 0x1b, 0x7e, 0xe0, 0x9e, 0xba, 0x9e, 0xd3, 0xb2, 0x2f, 0x24,
		0x99, 0x3e, 0xea, 0xeb, 0x31, 0xb5, 0x96, 0x4c, 0xb6, 0xf0, 0xa7, 0x0c, 0x5c, 0x8d, 0xed, 0xa9,
		0xec, 0x37, 0x9c, 0x96, 0xe6, 0x86, 0x1d, 0x87, 0x36, 0xce, 0xa6, 0x73, 0xd3, 0xff, 0x7d, 0xb9,
		0x7e, 0x0e, 0xb7, 0x06, 0x33, 0xb0, 0xfd, 0x13, 0x9b, 0x9e, 0xb9, 0xa1, 0x9d, 0xac, 0xe2, 0x64,
		0xc1, 0x6b, 0x03, 0x19, 0x55, 0x4e, 0xac, 0x33, 0x37, 0x14, 0x1e, 0x84, 0x6e, 0x02, 0xf0, 0x53,
		0x02, 0xf5, 0xdf, 0x13, 0x8f, 0xd7, 0x79, 0x11, 0xf3, 0x63, 0x8d, 0xc5, 0x02, 0x85, 0xd7, 0x90,
		0x4b, 0x9e, 0xa5, 0x9e, 0xc3, 0x9c, 0x38, 0x8e, 0x49, 0x9b, 0xd9, 0xad, 0xdc, 0xa3, 0x2f, 0x52,
		0x8e, 0x63, 0xfc, 0xa4, 0x2a, 0x28, 0x85, 0x3f, 0x64, 0x60, 0x79, 0xf0, 0x16, 0xba, 0x0f, 0x2b,
		0xc7, 0xae, 0xe7, 0x04, 0xe7, 0x76, 0xe3, 0x8c, 0x34, 0xde, 0x87, 0xdd, 0xb6, 0xd8, 0x84, 0xe5,
		0x28, 0xac, 0x8a, 0x28, 0x5a, 0x87, 0xb9, 0xa0, 0xeb, 0xc5, 0x2f, 0xcb, 0x05, 0x3c, 0x1b, 0x74,
		0xd9, 0xa9, 0xe2, 0x05, 0x5c, 0x3f, 0x71, 0x83, 0x90, 0xbd, 0x60, 0xa2, 0x66, 0xb7, 0x1b, 0x7e,
		0xbb, 0xd3, 0x22, 0x03, 0x13, 0x9b, 0xe7, 0x90, 0x78, 0x1c, 0xd4, 0x18, 0xc0, 0xe9, 0x8b, 0x8d,
		0x80, 0x38, 0xbd, 0xbd, 0x49, 0x2f, 0x65, 0x4e, 0xe0, 0x85, 0x6d, 0x2e, 0x71, 0x23, 0x75, 0xbd,
		0xd3, 0x69, 0xdb, 0x74, 0x31, 0x26, 0x70, 0x81, 0x5b, 0x00, 0xfc, 0x8c, 0x4b, 0x9d, 0xe3, 0x56,
		0xf4, 0x16, 0x9a, 0xc7, 0x89, 0x48, 0xf1, 0x8f, 0x12, 0x5c, 0x1e, 0xf5, 0x8e, 0x45, 0x05, 0xb8,
		0x55, 0xd5, 0x4d, 0xcd, 0x30, 0x5f, 0xd9, 0x8a, 0x6a, 0x19, 0x6f, 0x0d, 0xeb, 0xc8, 0xae, 0x59,
		0x8a, 0xa5, 0xdb, 0x86, 0xf9, 0x56, 0x29, 0x1b, 0x9a, 0xfc, 0x7f, 0xe8, 0xff, 0x61, 0x73, 0x0c,
		0xa6, 0xa6, 0xee, 0xeb, 0x5a, 0xbd, 0xac, 0x6b, 0xb2, 0x34, 0x41, 0xa9, 0x66, 0x29, 0xd8, 0xd2,
		0x35, 0x39, 0x83, 0x7e, 0x00, 0xf7, 0xc7, 0x60, 0x54, 0xc5, 0x54, 0xf5, 0xb2, 0x8d, 0xf5, 0x9f,
		0xd6, 0xf5, 0x1a, 0x03, 0x67, 0x8b, 0xbf, 0xe8, 0xe7, 0x3c, 0xe0, 0x40, 0xc9, 0x27, 0x69, 0xba,
		0x6a, 0xd4, 0x8c, 0x8a, 0x39, 0x29, 0xe7, 0x0b, 0x98, 0x31, 0x39, 0x5f, 0x44, 0xc5, 0x39, 0x17,
		0x7f, 0x99, 0xe9, 0x7f, 0x02, 0x1b, 0x4d, 0x4c, 0xba, 0xb1, 0xb7, 0xb2, 0x67, 0x1c, 0x56, 0xf0,
		0x9b, 0xbd, 0x72, 0xe5, 0xd0, 0x36, 0x34, 0x1b, 0xeb, 0xf5, 0x9a, 0x6e, 0x57, 0x2b, 0x65, 0x43,
		0x3d, 0x4a, 0x64, 0xf2, 0x43, 0xf8, 0x7a, 0x2c, 0x4a, 0x29, 0xb3, 0xa8, 0x56, 0xaf, 0x96, 0x0d,
		0x95, 0x3d, 0x75, 0x4f, 0x31, 0xca, 0xba, 0x66, 0x57, 0xcc, 0xf2, 0x91, 0x2c, 0xa1, 0x2f, 0x61,
		0x6b, 0x5a, 0xa6, 0x9c, 0x41, 0x0f, 0xe1, 0xc1, 0x58, 0x34, 0xd6, 0x5f, 0xeb, 0xaa, 0x95, 0x80,
		0x67, 0xd1, 0x0e, 0x3c, 0x1c, 0x0b, 0xb7, 0x74, 0x7c, 0x60, 0x98, 0xbc, 0xa0, 0x7b, 0x36, 0xae,
		0x9b, 0xa6, 0x61, 0xbe, 0x92, 0x67, 0x8a, 0xbf, 0x93, 0x60, 0x75, 0xe8, 0xa5, 0x83, 0x6e, 0xc3,
		0xf5, 0xaa, 0x82, 0x75, 0xd3, 0xb2, 0xd5, 0x72, 0x65, 0x54, 0x01, 0xc6, 0x00, 0x94, 0x5d, 0xc5,
		0xd4, 0x2a, 0xa6, 0x2c, 0xa1, 0x7b, 0x50, 0x18, 0x05, 0x10, 0xbd, 0x20, 0x5a, 0x43, 0xce, 0xa0,
		0x3b, 0x70, 0x73, 0x14, 0xae, 0x97, 0xad, 0x9c, 0x2d, 0xfe, 0x2b, 0x03, 0x37, 0x26, 0x7d, 0x69,
		0xb3, 0x0e, 0xec, 0x2d, 0x5b, 0x7f, 0xa7, 0xab, 0x75, 0x8b, 0xed, 0x79, 0xa4, 0xc7, 0x76, 0xbe,
		0x5e, 0x4b, 0x64, 0x9e, 0x2c, 0xe9, 0x18, 0xb0, 0x5a, 0x39, 0xa8, 0x96, 0x75, 0x8b, 0x77, 0x53,
		0x11, 0xee, 0xa5, 0xc1, 0xa3, 0x0d, 0x96, 0x33, 0x03, 0x7b, 0x3b, 0x4e, 0x9a, 0xaf, 0x9b, 0x8d,
		0x02, 0x2a, 0x41, 0x31, 0x0d, 0xdd, 0xab, 0x82, 0x26, 0xcf, 0xa0, 0xaf, 0xe1, 0xab, 0xf4, 0xc4,
		0x4d, 0xcb, 0x30, 0xeb, 0xba, 0x66, 0x2b, 0x35, 0xdb, 0xd4, 0x0f, 0xe5, 0xd9, 0x69, 0x96, 0x6b,
		0x19, 0x07, 0xac, 0x3f, 0xeb, 0x96, 0x3c, 0x57, 0xfc, 0xb3, 0x04, 0x57, 0x54, 0xdf, 0xa3, 0xae,
		0xd7, 0x25, 0x4a, 0x68, 0x92, 0x8f, 0x46, 0x74, 0x9e, 0xf1, 0x03, 0x74, 0x17, 0xee, 0xc4, 0xfa,
		0x42, 0xde, 0x36, 0x4c, 0xc3, 0x32, 0x14, 0xab, 0x82, 0x13, 0xf5, 0x9d, 0x08, 0x63, 0x03, 0xa9,
		0xe9, 0x38, 0xaa, 0xeb, 0x78, 0x18, 0xd6, 0x2d, 0x7c, 0x24, 0x5a, 0x21, 0x72, 0x98, 0xf1, 0x58,
		0x15, 0xb3, 0xf9, 0x16, 0xf3, 0x2f, 0x67, 0x8b, 0xbf, 0x97, 0x20, 0x27, 0xbe, 0x45, 0xf9, 0xa7,
		0x4a, 0x1e, 0x2e, 0xb3, 0x05, 0x56, 0xea, 0x96, 0x6d, 0x1d, 0x55, 0xf5, 0xc1, 0x1e, 0x1e, 0xb8,
		0xc3, 0xed, 0xc1, 0xb6, 0x2a, 0x51, 0x75, 0x22, 0x27, 0x19, 0x04, 0x88, 0xa7, 0x30, 0x0c, 0x07,
		0xcb, 0x99, 0x89, 0x98, 0x48, 0x27, 0x8b, 0xae, 0xc1, 0x95, 0x01, 0xcc, 0xbe, 0xae, 0x60, 0x6b,
		0x57, 0x57, 0x2c, 0x79, 0xa6, 0xf8, 0x1b, 0x09, 0xae, 0xc6, 0x4e, 0x68, 0xb1, 0x17, 0xab, 0xdb,
		0x26, 0xcd, 0x4a, 0x97, 0xaa, 0x4e, 0x37, 0x24, 0xe8, 0x01, 0xdc, 0xed, 0x79, 0x98, 0xa5, 0xd4,
		0xde, 0xf4, 0xf7, 0xca, 0x56, 0x15, 0x36, 0xdc, 0xfd, 0xd5, 0xa4, 0x42, 0x45, 0x0a, 0xb2, 0x84,
		0xee, 0xc3, 0x17, 0x93, 0xa1, 0x58, 0xaf, 0xe9, 0x96, 0x9c, 0x29, 0xfe, 0x23, 0x07, 0x1b, 0xc9,
		0xe4, 0xd8, 0x81, 0x9e, 0x34, 0xa3, 0xd4, 0xee, 0x41, 0x61, 0x50, 0x44, 0xf8, 0xdc, 0xc5, 0xbc,
		0x76, 0xe0, 0xe1, 0x04, 0x5c, 0xdd, 0xdc, 0x57, 0x4c, 0x8d, 0x5d, 0xc7, 0x20, 0x59, 0x42, 0x2f,
		0xe1, 0xf9, 0x04, 0xca, 0xae, 0xa2, 0xf5, 0xab, 0xdc, 0x7b, 0xe3, 0x28, 0x96, 0x85, 0x8d, 0xdd,
		0xba, 0xa5, 0xd7, 0xe4, 0x0c, 0xd2, 0x41, 0x49, 0x11, 0x18, 0xf4, 0xa1, 0x91, 0x32, 0x59, 0xf4,
		0x0c, 0x9e, 0xa4, 0xe5, 0x11, 0xb5, 0x8c, 0x71, 0xa0, 0xe3, 0x24, 0x75, 0x06, 0x7d, 0x0b, 0xdf,
		0xa4, 0x50, 0xc5, 0x93, 0x87, 0xb8, 0xb3, 0xe8, 0x39, 0x3c, 0x4d, 0xcd, 0x5e, 0xad, 0x60, 0xcd,
		0x3e, 0x50, 0xf0, 0x9b, 0x41, 0xf2, 0x1c, 0x32, 0x40, 0x4f, 0x7b, 0xb0, 0x70, 0x37, 0x7b, 0x84,
		0x2f, 0x24, 0xa4, 0x2e, 0x4d, 0x51, 0x45, 0x16, 0x48, 0x91, 0x99, 0x47, 0xaf, 0x40, 0x9d, 0xae,
		0x14, 0x93, 0x85, 0x16, 0xd0, 0x3b, 0xb0, 0x3e, 0x6f, 0x57, 0xf5, 0x77, 0x96, 0x8e, 0x4d, 0x25,
		0x4d, 0x19, 0xd0, 0x0b, 0x78, 0x96, 0x5a, 0xb4, 0x41, 0xff, 0x49, 0xd0, 0x73, 0xe8, 0x29, 0x3c,
		0x9e, 0x40, 0x4f, 0xf6, 0x48, 0xff, 0x54, 0x60, 0x68, 0xf2, 0x22, 0x7a, 0x02, 0x3b, 0x13, 0x88,
		0x7c, 0x0a, 0xed, 0x9a, 0x65, 0xa8, 0x6f, 0x8e, 0xa2, 0xdb, 0x65, 0xa3, 0x66, 0xc9, 0x4b, 0xe8,
		0x27, 0xf0, 0xa3, 0x09, 0xb4, 0xde, 0x62, 0xd9, 0x1f, 0x3a, 0x4e, 0x8c, 0x18, 0x83, 0xd5, 0xb1,
		0x2e, 0x2f, 0x4f, 0xb1, 0x27, 0x35, 0xe3, 0x55, 0x7a, 0xe5, 0x56, 0x90, 0x0a, 0x2f, 0xa7, 0x1a,
		0x11, 0x75, 0xdf, 0x28, 0x6b, 0xa3, 0x45, 0x64, 0xf4, 0x18, 0xb6, 0x27, 0x88, 0xec, 0x55, 0xb0,
		0xaa, 0x8b, 0x37, 0x56, 0xcf, 0x24, 0x56, 0xd1, 0x37, 0xf0, 0x68, 0x12, 0x49, 0x31, 0xca, 0x95,
		0xb7, 0x3a, 0xbe, 0xc8, 0x43, 0xec, 0x35, 0x3a, 0xdd, 0xd2, 0x0d, 0xb3, 0x5a, 0xb7, 0xec, 0x9a,
		0xf1, 0x9d, 0x2e, 0xaf, 0xb1, 0xd7, 0x68, 0xea, 0x4e, 0xc5, 0xb5, 0x92, 0x2f, 0x0f, 0x9b, 0xf1,
		0xd0, 0x43, 0x76, 0x0d, 0x53, 0xc1, 0x47, 0xf2, 0x7a, 0x4a, 0xef, 0x0d, 0x1b, 0xdd, 0x40, 0x0b,
		0x5d, 0x99, 0x66, 0x39, 0xba, 0x82, 0xd5, 0xfd, 0x64, 0xc5, 0x37, 0xd8, 0x5b, 0xe7, 0x0e, 0xff,
		0xc7, 0xca, 0xd0, 0xb9, 0x2a, 0x69, 0xf1, 0x3b, 0xf0, 0x30, 0xda, 0xb7, 0x11, 0x5d, 0x30, 0xc6,
		0xed, 0x77, 0xe1, 0xc7, 0xd3, 0x51, 0x7a, 0xf7, 0x95, 0x32, 0xd6, 0x15, 0xed, 0xa8, 0x77, 0x24,
		0x95, 0x8a, 0x7f, 0x95, 0xa0, 0xa8, 0x3a, 0x5e, 0x83, 0xb4, 0xe2, 0xff, 0xbb, 0x4e, 0xcc, 0xf2,
		0x39, 0x3c, 0x9d, 0x62, 0xde, 0xc7, 0xe4, 0x7b, 0x08, 0xb5, 0xcf, 0x25, 0xd7, 0xcd, 0x37, 0x66,
		0xe5, 0xd0, 0x9c, 0x44, 0x10, 0x8b, 0xa8, 0xb9, 0xa7, 0xfc, 0x9f, 0xc6, 0xd3, 0x2d, 0x42, 0xb4,
		0xdd, 0x7f, 0xb6, 0x88, 0xcf, 0x25, 0x4f, 0xb5, 0x88, 0xdd, 0xb7, 0xb0, 0xd1, 0xf0, 0xdb, 0xa3,
		0xbe, 0xe2, 0x77, 0xe7, 0x95, 0x8e, 0x5b, 0x65, 0x5f, 0xb0, 0x55, 0xe9, 0xbb, 0xed, 0x53, 0x97,
		0x9e, 0x75, 0x8f, 0x4b, 0x0d, 0xbf, 0xbd, 0x3d, 0xf0, 0xfb, 0x63, 0xe9, 0x94, 0x78, 0xd1, 0xaf,
		0x99, 0xe2, 0xa7, 0xc8, 0xe7, 0x4e, 0xc7, 0xfd, 0xb0, 0x73, 0x3c, 0xc7, 0x63, 0x8f, 0xff, 0x1d,
		0x00, 0x00, 0xff, 0xff, 0x1c, 0xfe, 0xdc, 0x7d, 0x4a, 0x1d, 0x00, 0x00,
	},
	// uber/cadence/api/v1/query.proto
	[]byte{
		0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0x8c, 0x53, 0x4d, 0x6f, 0xd3, 0x40,
		0x14, 0xc4, 0x41, 0xaa, 0xe8, 0x6b, 0x0b, 0xd6, 0x16, 0x44, 0xa8, 0xfa, 0x11, 0xa5, 0x3d, 0x54,
		0x11, 0xb2, 0x49, 0xe1, 0xd6, 0x93, 0xeb, 0x2c, 0xc8, 0xc8, 0xb5, 0x5d, 0x7b, 0x93, 0x2a, 0x5c,
		0x2c, 0xc7, 0x59, 0x82, 0x69, 0xe2, 0x35, 0xbb, 0x76, 0x42, 0xfe, 0x00, 0x77, 0x7e, 0x0d, 0x7f,
		0x0f, 0xd9, 0x71, 0x48, 0x4a, 0x5c, 0xc4, 0xed, 0x79, 0xde, 0x8c, 0x67, 0x46, 0xab, 0x07, 0x27,
		0xd9, 0x80, 0x72, 0x35, 0x0c, 0x86, 0x34, 0x0e, 0xa9, 0x1a, 0x24, 0x91, 0x3a, 0x6d, 0xab, 0xdf,
		0x32, 0xca, 0xe7, 0x4a, 0xc2, 0x59, 0xca, 0xd0, 0x7e, 0x4e, 0x50, 0x4a, 0x82, 0x12, 0x24, 0x91,
		0x32, 0x6d, 0x1f, 0x34, 0xaa, 0x54, 0x21, 0x9b, 0x4c, 0x58, 0xbc, 0x90, 0x1d, 0x34, 0xab, 0x18,
		0x33, 0xc6, 0xef, 0x3e, 0x8f, 0xd9, 0x6c, 0xc1, 0x69, 0xde, 0xc1, 0xde, 0x6d, 0x89, 0xdc, 0xe4,
		0x8e, 0xe8, 0x08, 0xa0, 0xb0, 0xf6, 0xd3, 0x79, 0x42, 0xeb, 0x52, 0x43, 0x3a, 0xdf, 0x76, 0xb7,
		0x0b, 0x84, 0xcc, 0x13, 0x8a, 0x2e, 0x97, 0xeb, 0x80, 0x8f, 0x44, 0xbd, 0xd6, 0x90, 0xce, 0x77,
		0x2e, 0x0e, 0x95, 0x8a, 0x7c, 0x8a, 0x13, 0xcc, 0xc7, 0x2c, 0x18, 0x96, 0x62, 0x8d, 0x8f, 0x44,
		0xf3, 0x97, 0x04, 0xfb, 0xf7, 0xdc, 0x5c, 0x2a, 0xb2, 0x71, 0x8a, 0x30, 0xec, 0xf0, 0x62, 0x5a,
		0x99, 0x3e, 0xbd, 0x38, 0xab, 0xfc, 0xeb, 0x9a, 0x2c, 0xcf, 0xe3, 0x02, 0xff, 0x33, 0xa3, 0x77,
		0xb0, 0x15, 0xc4, 0x62, 0x46, 0xf9, 0x7f, 0xe5, 0x2a, 0xb9, 0xe8, 0x14, 0xf6, 0x28, 0xe7, 0x8c,
		0xfb, 0x13, 0x2a, 0x44, 0x30, 0xa2, 0xf5, 0xc7, 0x45, 0xe7, 0xdd, 0x02, 0xbc, 0x5e, 0x60, 0x4d,
		0x0a, 0x7b, 0xa5, 0xf3, 0x57, 0x1a, 0xa6, 0x74, 0x88, 0x08, 0xec, 0x86, 0x63, 0x26, 0xa8, 0x2f,
		0xd2, 0x20, 0xcd, 0x44, 0x99, 0xb9, 0x5d, 0xe9, 0xb8, 0xac, 0x8c, 0xbf, 0xd3, 0x30, 0x4b, 0x23,
		0x16, 0xeb, 0xb9, 0xd2, 0x2b, 0x84, 0xee, 0x4e, 0xb8, 0xfa, 0x68, 0xc5, 0xf0, 0xec, 0xaf, 0x82,
		0xe8, 0x08, 0x5e, 0xdd, 0x74, 0xb1, 0xdb, 0xf7, 0x5d, 0xec, 0x75, 0x4d, 0xe2, 0x93, 0xbe, 0x83,
		0x7d, 0xc3, 0xea, 0x69, 0xa6, 0xd1, 0x91, 0x1f, 0xa1, 0x63, 0x38, 0xd8, 0x5c, 0x6b, 0x96, 0x77,
		0x8b, 0x5d, 0xdc, 0x91, 0x25, 0x74, 0x08, 0xf5, 0xcd, 0xfd, 0x7b, 0xcd, 0x30, 0x71, 0x47, 0xae,
		0xb5, 0x7e, 0x4a, 0xf0, 0x7c, 0xad, 0x97, 0xce, 0xe2, 0x61, 0x94, 0x07, 0x44, 0x4d, 0x38, 0x5e,
		0xca, 0x3e, 0x62, 0x9d, 0xf8, 0xba, 0x6d, 0x75, 0x0c, 0x62, 0xd8, 0xd6, 0x9a, 0xf5, 0x29, 0x9c,
		0x3c, 0xc0, 0xb1, 0x6c, 0xe2, 0xdb, 0x0e, 0xb6, 0x64, 0x09, 0xbd, 0x81, 0xd7, 0xff, 0x20, 0xe9,
		0xf6, 0xb5, 0x63, 0x62, 0x82, 0x3b, 0xbe, 0x6e, 0x62, 0xcd, 0x32, 0xfb, 0x72, 0xad, 0xf5, 0x43,
		0x82, 0x17, 0x45, 0x26, 0x9d, 0xc5, 0x22, 0x12, 0x29, 0x8d, 0xc3, 0xb9, 0x49, 0xa7, 0x74, 0xbc,
		0x32, 0xd4, 0x6d, 0xcb, 0x33, 0x3c, 0x82, 0x2d, 0xbd, 0xef, 0x9b, 0xb8, 0x87, 0xcd, 0xb5, 0x54,
		0x67, 0xd0, 0x78, 0x88, 0x84, 0x7b, 0xd8, 0x22, 0x5d, 0xcd, 0x94, 0xa5, 0x55, 0xbf, 0x4d, 0x96,
		0x47, 0x5c, 0xdb, 0xfa, 0x20, 0xd7, 0xae, 0x7a, 0xf0, 0x32, 0x64, 0x93, 0xaa, 0x17, 0xbd, 0x7a,
		0xa2, 0x25, 0x91, 0x93, 0xdf, 0x8f, 0x23, 0x7d, 0x52, 0x47, 0x51, 0xfa, 0x25, 0x1b, 0x28, 0x21,
		0x9b, 0xa8, 0xf7, 0x0e, 0x4e, 0x19, 0xd1, 0x58, 0x2d, 0xae, 0xac, 0xbc, 0xbd, 0xcb, 0x20, 0x89,
		0xa6, 0xed, 0xc1, 0x56, 0x81, 0xbd, 0xfd, 0x1d, 0x00, 0x00, 0xff, 0xff, 0x96, 0x7d, 0xf9, 0x10,
		0xf7, 0x03, 0x00, 0x00,
	},
}

func init() {
	yarpc.RegisterClientBuilder(
		func(clientConfig transport.ClientConfig, structField reflect.StructField) WorkflowAPIYARPCClient {
			return NewWorkflowAPIYARPCClient(clientConfig, protobuf.ClientBuilderOptions(clientConfig, structField)...)
		},
	)
}
